@@ -15,8 +15,7 @@
 #
 # You should have received a copy of the GNU General Public License along with
 # satpy.  If not, see <http://www.gnu.org/licenses/>.
-"""Composite classes for the VIIRS instrument.
-"""
+"""Composite classes for the VIIRS instrument."""
 
 import logging
 import os
@@ -29,14 +28,16 @@ import xarray as xr
 from satpy.composites import CompositeBase, GenericCompositor
 from satpy.config import get_environ_ancpath
 from satpy.dataset import combine_metadata
+from satpy.utils import get_satpos
 
 LOG = logging.getLogger(__name__)
 
 
 class VIIRSFog(CompositeBase):
+    """A simple temperature difference composite for showing fog."""
 
     def __call__(self, projectables, nonprojectables=None, **info):
-
+        """Create the temperature difference DataArray."""
         import warnings
         warnings.warn("VIIRSFog compositor is deprecated, use DifferenceCompositor "
                       "instead.", DeprecationWarning)
@@ -58,8 +59,7 @@ class VIIRSFog(CompositeBase):
 
 
 class ReflectanceCorrector(CompositeBase):
-
-    """CREFL modifier
+    """Corrected Reflectance (crefl) modifier.
 
     Uses a python rewrite of the C CREFL code written for VIIRS and MODIS.
     """
@@ -86,6 +86,7 @@ class ReflectanceCorrector(CompositeBase):
         super(ReflectanceCorrector, self).__init__(*args, **kwargs)
 
     def __call__(self, datasets, optional_datasets, **info):
+        """Create modified DataArray object by applying the crefl algorithm."""
         if not optional_datasets or len(optional_datasets) != 4:
             vis = self.match_data_arrays([datasets[0]])[0]
             sensor_aa, sensor_za, solar_aa, solar_za = self.get_angles(vis)
@@ -127,7 +128,7 @@ class ReflectanceCorrector(CompositeBase):
                                         refl_data.attrs["wavelength"],
                                         refl_data.attrs["resolution"])
         use_abi = vis.attrs['sensor'] == 'abi'
-        lons, lats = vis.attrs['area'].get_lonlats_dask(chunks=vis.chunks)
+        lons, lats = vis.attrs['area'].get_lonlats(chunks=vis.chunks)
         results = run_crefl(refl_data,
                             coefficients,
                             lons,
@@ -148,18 +149,20 @@ class ReflectanceCorrector(CompositeBase):
         return results
 
     def get_angles(self, vis):
+        """Get sun and satellite angles to use in crefl calculations."""
         from pyorbital.astronomy import get_alt_az, sun_zenith_angle
         from pyorbital.orbital import get_observer_look
-
-        lons, lats = vis.attrs['area'].get_lonlats_dask(
-            chunks=vis.data.chunks)
+        lons, lats = vis.attrs['area'].get_lonlats(chunks=vis.data.chunks)
+        lons = da.where(lons >= 1e30, np.nan, lons)
+        lats = da.where(lats >= 1e30, np.nan, lats)
         suna = get_alt_az(vis.attrs['start_time'], lons, lats)[1]
         suna = np.rad2deg(suna)
         sunz = sun_zenith_angle(vis.attrs['start_time'], lons, lats)
+        sat_lon, sat_lat, sat_alt = get_satpos(vis)
         sata, satel = get_observer_look(
-            vis.attrs['satellite_longitude'],
-            vis.attrs['satellite_latitude'],
-            vis.attrs['satellite_altitude'],
+            sat_lon,
+            sat_lat,
+            sat_alt / 1000.0,  # km
             vis.attrs['start_time'],
             lons, lats, 0)
         satz = 90 - satel
@@ -393,6 +396,7 @@ class ERFDNB(CompositeBase):
     """
 
     def __init__(self, *args, **kwargs):
+        """Initialize ERFDNB specific keyword arguments."""
         self.saturation_correction = kwargs.pop("saturation_correction",
                                                 False)
         super(ERFDNB, self).__init__(*args, **kwargs)
@@ -415,6 +419,7 @@ class ERFDNB(CompositeBase):
         return np.sqrt(inner_sqrt)
 
     def __call__(self, datasets, **info):
+        """Create the composite DataArray object for ERFDNB."""
         if len(datasets) != 4:
             raise ValueError("Expected 4 datasets, got %d" % (len(datasets), ))
 
@@ -490,17 +495,17 @@ def make_day_night_masks(solarZenithAngle,
                          highAngleCutoff,
                          lowAngleCutoff,
                          stepsDegrees=None):
-    """
-    given information on the solarZenithAngle for each point,
-    generate masks defining where the day, night, and mixed regions are
+    """Generate masks for day, night, and twilight regions.
 
-    optionally provide the highAngleCutoff and lowAngleCutoff that define
+    Masks are created from the provided solar zenith angle data.
+
+    Optionally provide the highAngleCutoff and lowAngleCutoff that define
     the limits of the terminator region (if no cutoffs are given the
-    DEFAULT_HIGH_ANGLE and DEFAULT_LOW_ANGLE will be used)
+    DEFAULT_HIGH_ANGLE and DEFAULT_LOW_ANGLE will be used).
 
-    optionally provide the stepsDegrees that define how many degrees each
+    Optionally provide the stepsDegrees that define how many degrees each
     "mixed" mask in the terminator region should be (if no stepsDegrees is
-    given, the whole terminator region will be one mask)
+    given, the whole terminator region will be one mask).
     """
     # if the caller passes None, we're only doing one step
     stepsDegrees = highAngleCutoff - lowAngleCutoff if stepsDegrees is None else stepsDegrees
@@ -543,8 +548,9 @@ def histogram_equalization(
         log_offset=None,
         local_radius_px=None,
         out=None):
-    """
-    Perform a histogram equalization on the data selected by mask_to_equalize.
+    """Perform a histogram equalization on the data.
+
+    Data is selected by the mask_to_equalize mask.
     The data will be separated into number_of_bins levels for equalization and
     outliers beyond +/- std_mult_cutoff*std will be ignored.
 
@@ -554,7 +560,6 @@ def histogram_equalization(
 
     Note: the data will be changed in place.
     """
-
     out = out if out is not None else data.copy()
     mask_to_use = mask_to_equalize if valid_data_mask is None else valid_data_mask
 
@@ -601,22 +606,18 @@ def local_histogram_equalization(data, mask_to_equalize, valid_data_mask=None, n
                                  ):
     """Equalize the provided data (in the mask_to_equalize) using adaptive histogram equalization.
 
-    tiles of width/height (2 * local_radius_px + 1) will be calculated and results for each pixel will be bilinerarly
+    Tiles of width/height (2 * local_radius_px + 1) will be calculated and results for each pixel will be bilinearly
     interpolated from the nearest 4 tiles when pixels fall near the edge of the image (there is no adjacent tile) the
-    resultant interpolated sum from the available tiles will be multipled to account for the weight of any missing
+    resultant interpolated sum from the available tiles will be multiplied to account for the weight of any missing
     tiles::
 
         pixel total interpolated value = pixel available interpolated value / (1 - missing interpolation weight)
 
-    if ``do_zerotoone_normalization`` is True the data will be scaled so that all data in the mask_to_equalize falls
-    between 0 and 1; otherwise the data in mask_to_equalize will all fall between 0 and number_of_bins
-
-    Returns:
-
-        The equalized data
+    If ``do_zerotoone_normalization`` is True the data will be scaled so that all data in the mask_to_equalize falls
+    between 0 and 1; otherwise the data in mask_to_equalize will all fall between 0 and number_of_bins.
 
+    Returns: The equalized data
     """
-
     out = out if out is not None else np.zeros_like(data)
     # if we don't have a valid mask, use the mask of what we should be
     # equalizing
@@ -821,7 +822,6 @@ def _histogram_equalization_helper(valid_data, number_of_bins, clip_limit=None,
         cumulative distribution function and bin information
 
     """
-
     # bucket all the selected data using np's histogram function
     temp_histogram, temp_bins = np.histogram(valid_data, number_of_bins)
 
@@ -871,17 +871,17 @@ def _histogram_equalization_helper(valid_data, number_of_bins, clip_limit=None,
 
 
 def _calculate_weights(tile_size):
-    """
-    calculate a weight array that will be used to quickly bilinearly-interpolate the histogram equalizations
-    tile size should be the width and height of a tile in pixels
+    """Calculate a weight array for bilinear interpolation of histogram tiles.
 
-    returns a 4D weight array, where the first 2 dimensions correspond to the grid of where the tiles are
-    relative to the tile being interpolated
-    """
+    The weight array will be used to quickly bilinearly-interpolate the
+    histogram equalizations tile size should be the width and height of a tile
+    in pixels.
 
+    Returns: 4D weight array where the first 2 dimensions correspond to the
+        grid of where the tiles are relative to the tile being interpolated.
+    """
     # we are essentially making a set of weight masks for an ideal center tile
     # that has all 8 surrounding tiles available
-
     # create our empty template tiles
     template_tile = np.zeros((3, 3, tile_size, tile_size), dtype=np.float32)
     """
@@ -996,7 +996,6 @@ def _linear_normalization_from_0to1(
     the correct theoretical current max and min so it can scale the data
     accordingly.
     """
-
     LOG.debug(message)
     if theoretical_min != 0:
         data[mask] = data[mask] - theoretical_min
@@ -1008,14 +1007,16 @@ class NCCZinke(CompositeBase):
     """Equalized DNB composite using the Zinke algorithm [#ncc1]_.
 
     References:
-
         .. [#ncc1] Stephan Zinke (2017),
-               A simplified high and near-constant contrast approach for the display of VIIRS day/night band imagery
+
+               A simplified high and near-constant contrast approach for the
+               display of VIIRS day/night band imagery
                :doi:`10.1080/01431161.2017.1338838`
 
     """
 
     def __call__(self, datasets, **info):
+        """Create HNCC DNB composite."""
         if len(datasets) != 4:
             raise ValueError("Expected 4 datasets, got %d" % (len(datasets),))
 
@@ -1058,8 +1059,8 @@ class NCCZinke(CompositeBase):
         return dnb_data
 
     def gain_factor(self, theta):
-        return theta.map_blocks(self._gain_factor,
-                                dtype=theta.dtype)
+        """Compute gain factor in a dask-friendly manner."""
+        return theta.map_blocks(self._gain_factor, dtype=theta.dtype)
 
     @staticmethod
     def _gain_factor(theta):
