@@ -21,7 +21,7 @@ import numpy as np
 
 from satpy.dataset import create_filtered_query, ModifierTuple
 from satpy.dataset.data_dict import TooManyResults, get_key
-from satpy.node import CompositorNode, Node, EMPTY_LEAF_NAME, MissingDependencies, LOG
+from satpy.node import CompositorNode, Node, EMPTY_LEAF_NAME, MissingDependencies, LOG, ReaderNode
 
 
 class Tree:
@@ -289,17 +289,13 @@ class DependencyTree(Tree):
 
         """
         matching_ids = self._find_matching_ids_in_readers(dataset_key)
-        result = self._get_unique_matching_id(matching_ids, dataset_key, query)
+        unique_id = self._get_unique_matching_id(matching_ids, dataset_key, query)
 
         for reader_name, ids in matching_ids.items():
-            if result in ids:
-                data = {'reader_name': reader_name}
-                break
-        else:
-            raise RuntimeError("Data ID disappeared.")
+            if unique_id in ids:
+                return self._get_unique_reader_node_from_id(unique_id, reader_name)
 
-        result = self._get_unique_node_from_id(result, data)
-        return result
+        raise RuntimeError("Data ID disappeared.")
 
     def _find_matching_ids_in_readers(self, dataset_key):
         matching_ids = {}
@@ -343,13 +339,13 @@ class DependencyTree(Tree):
             raise MissingDependencies
         return result
 
-    def _get_unique_node_from_id(self, result, data):
+    def _get_unique_reader_node_from_id(self, data_id, reader_name):
         try:
             # now that we know we have the exact DataID see if we have already created a Node for it
-            return self.getitem(result)
+            return self.getitem(data_id)
         except KeyError:
             # we haven't created a node yet, create it now
-            return Node(result, data)
+            return ReaderNode(data_id, reader_name)
 
     def _get_subtree_for_existing_name(self, dsq):
         try:
