@@ -18,14 +18,17 @@
 """Advance Baseline Imager reader base class for the Level 1b and l2+ reader."""
 
 import logging
+from contextlib import suppress
 from datetime import datetime
 
 import numpy as np
 import xarray as xr
-
 from pyresample import geometry
-from satpy.readers.file_handlers import BaseFileHandler
+
 from satpy import CHUNK_SIZE
+from satpy._compat import cached_property
+from satpy.readers import open_file_or_filename
+from satpy.readers.file_handlers import BaseFileHandler
 
 logger = logging.getLogger(__name__)
 
@@ -41,33 +44,40 @@ class NC_ABI_BASE(BaseFileHandler):
     def __init__(self, filename, filename_info, filetype_info):
         """Open the NetCDF file with xarray and prepare the Dataset for reading."""
         super(NC_ABI_BASE, self).__init__(filename, filename_info, filetype_info)
-        # xarray's default netcdf4 engine
-        try:
-            self.nc = xr.open_dataset(self.filename,
-                                      decode_cf=True,
-                                      mask_and_scale=False,
-                                      chunks={'x': CHUNK_SIZE, 'y': CHUNK_SIZE}, )
-        except ValueError:
-            self.nc = xr.open_dataset(self.filename,
-                                      decode_cf=True,
-                                      mask_and_scale=False,
-                                      chunks={'lon': CHUNK_SIZE, 'lat': CHUNK_SIZE}, )
 
-        if 't' in self.nc.dims or 't' in self.nc.coords:
-            self.nc = self.nc.rename({'t': 'time'})
         platform_shortname = filename_info['platform_shortname']
         self.platform_name = PLATFORM_NAMES.get(platform_shortname)
 
-        if 'goes_imager_projection' in self.nc:
-            self.nlines = self.nc['y'].size
-            self.ncols = self.nc['x'].size
-        elif 'goes_lat_lon_projection' in self.nc:
-            self.nlines = self.nc['lat'].size
-            self.ncols = self.nc['lon'].size
-            self.nc = self.nc.rename({'lon': 'x', 'lat': 'y'})
+        self.nlines = self.nc['y'].size
+        self.ncols = self.nc['x'].size
 
         self.coords = {}
 
+    @cached_property
+    def nc(self):
+        """Get the xarray dataset for this file."""
+        f_obj = open_file_or_filename(self.filename)
+        try:
+            nc = xr.open_dataset(f_obj,
+                                 decode_cf=True,
+                                 mask_and_scale=False,
+                                 chunks={'x': CHUNK_SIZE, 'y': CHUNK_SIZE}, )
+        except ValueError:
+            nc = xr.open_dataset(f_obj,
+                                 decode_cf=True,
+                                 mask_and_scale=False,
+                                 chunks={'lon': CHUNK_SIZE, 'lat': CHUNK_SIZE}, )
+        nc = self._rename_dims(nc)
+        return nc
+
+    @staticmethod
+    def _rename_dims(nc):
+        if 't' in nc.dims or 't' in nc.coords:
+            nc = nc.rename({'t': 'time'})
+        if 'goes_lat_lon_projection' in nc:
+            nc = nc.rename({'lon': 'x', 'lat': 'y'})
+        return nc
+
     @property
     def sensor(self):
         """Get sensor name for current file handler."""
@@ -80,17 +90,27 @@ class NC_ABI_BASE(BaseFileHandler):
         variables which causes inaccurate unscaled data values. This method
         forces the scale factor to a 64-bit float first.
         """
-        def is_int(val):
-            return np.issubdtype(val.dtype, np.integer) if hasattr(val, 'dtype') else isinstance(val, int)
-
         data = self.nc[item]
         attrs = data.attrs
 
+        data = self._adjust_data(data, item)
+
+        data.attrs = attrs
+
+        data = self._adjust_coords(data, item)
+
+        return data
+
+    def _adjust_data(self, data, item):
+        """Adjust data with typing, scaling and filling."""
         factor = data.attrs.get('scale_factor', 1)
         offset = data.attrs.get('add_offset', 0)
         fill = data.attrs.get('_FillValue')
         unsigned = data.attrs.get('_Unsigned', None)
 
+        def is_int(val):
+            return np.issubdtype(val.dtype, np.integer) if hasattr(val, 'dtype') else isinstance(val, int)
+
         # Ref. GOESR PUG-L1B-vol3, section 5.0.2 Unsigned Integer Processing
         if unsigned is not None and unsigned.lower() == 'true':
             # cast the data from int to uint
@@ -98,14 +118,19 @@ class NC_ABI_BASE(BaseFileHandler):
 
             if fill is not None:
                 fill = fill.astype('u%s' % fill.dtype.itemsize)
-
         if fill is not None:
+            # Some backends (h5netcdf) may return attributes as shape (1,)
+            # arrays rather than shape () scalars, which according to the netcdf
+            # documentation at <URL:https://www.unidata.ucar.edu
+            # /software/netcdf/docs/netcdf_data_set_components.html#attributes>
+            # is correct.
+            if np.ndim(fill) > 0:
+                fill = fill.item()
             if is_int(data) and is_int(factor) and is_int(offset):
                 new_fill = fill
             else:
                 new_fill = np.nan
             data = data.where(data != fill, new_fill)
-
         if factor != 1 and item in ('x', 'y'):
             # be more precise with x/y coordinates
             # see get_area_def for more information
@@ -117,10 +142,10 @@ class NC_ABI_BASE(BaseFileHandler):
             if not is_int(factor):
                 factor = float(factor)
             data = data * factor + offset
+        return data
 
-        data.attrs = attrs
-
-        # handle coordinates (and recursive fun)
+    def _adjust_coords(self, data, item):
+        """Handle coordinates (and recursive fun)."""
         new_coords = {}
         # 'time' dimension causes issues in other processing
         # 'x_image' and 'y_image' are confusing to some users and unnecessary
@@ -135,7 +160,6 @@ class NC_ABI_BASE(BaseFileHandler):
                 self.coords[coord_name] = self[coord_name]
             new_coords[coord_name] = self.coords[coord_name]
         data.coords.update(new_coords)
-
         return data
 
     def get_dataset(self, key, info):
@@ -263,7 +287,5 @@ class NC_ABI_BASE(BaseFileHandler):
 
     def __del__(self):
         """Close the NetCDF file that may still be open."""
-        try:
+        with suppress(IOError, OSError, AttributeError):
             self.nc.close()
-        except (IOError, OSError, AttributeError):
-            pass
