@@ -81,8 +81,9 @@ class NC_ABI_L1B(NC_ABI_BASE):
         # although we could compute these, we'd have to update in calibration
         res.attrs.pop('valid_range', None)
         # add in information from the filename that may be useful to the user
-        for attr in ('observation_type', 'scene_abbr', 'scan_mode', 'platform_shortname'):
-            res.attrs[attr] = self.filename_info[attr]
+        for attr in ('observation_type', 'scene_abbr', 'scan_mode', 'platform_shortname', 'suffix'):
+            if attr in self.filename_info:
+                res.attrs[attr] = self.filename_info[attr]
         # copy global attributes to metadata
         for attr in ('scene_id', 'orbital_slot', 'instrument_ID', 'production_site', 'timeline_ID'):
             res.attrs[attr] = self.nc.attrs.get(attr)
