@@ -15,14 +15,16 @@
 #
 # You should have received a copy of the GNU General Public License along with
 # satpy.  If not, see <http://www.gnu.org/licenses/>.
-"""Reader for AMSR2 L1B files in HDF5 format.
-"""
+"""Reader for AMSR2 L1B files in HDF5 format."""
 
 from satpy.readers.hdf5_utils import HDF5FileHandler
 
 
 class AMSR2L1BFileHandler(HDF5FileHandler):
+    """File handler for AMSR2 l1b."""
+
     def get_metadata(self, ds_id, ds_info):
+        """Get the metadata."""
         var_path = ds_info['file_key']
         info = getattr(self[var_path], 'attrs', {})
         info.update(ds_info)
@@ -42,7 +44,7 @@ class AMSR2L1BFileHandler(HDF5FileHandler):
         var_path = ds_info['file_key']
         shape = self[var_path + '/shape']
         if ((ds_info.get('standard_name') == "longitude" or ds_info.get('standard_name') == "latitude") and
-                ds_id.resolution == 10000):
+                ds_id['resolution'] == 10000):
             return shape[0], int(shape[1] / 2)
         return shape
 
@@ -55,7 +57,7 @@ class AMSR2L1BFileHandler(HDF5FileHandler):
         data = self[var_path]
         if ((ds_info.get('standard_name') == "longitude" or
              ds_info.get('standard_name') == "latitude") and
-                ds_id.resolution == 10000):
+                ds_id['resolution'] == 10000):
             # FIXME: Lower frequency channels need CoRegistration parameters applied
             data = data[:, ::2] * self[var_path + "/attr/SCALE FACTOR"]
         else:
