@@ -161,6 +161,7 @@ class EPSAVHRRFile(BaseFileHandler):
         self.scanlines = self['TOTAL_MDR']
         if self.scanlines != len(self.sections[('mdr', 2)]):
             logger.warning("Number of declared records doesn't match number of scanlines in the file.")
+            self.scanlines = len(self.sections[('mdr', 2)])
         self.pixels = self["EARTH_VIEWS_PER_SCANLINE"]
 
     def __getitem__(self, key):
@@ -186,20 +187,8 @@ class EPSAVHRRFile(BaseFileHandler):
             keys += val.dtype.fields.keys()
         return keys
 
-    @delayed(nout=2, pure=True)
-    def _get_full_lonlats(self, lons, lats):
-        nav_sample_rate = self["NAV_SAMPLE_RATE"]
-        if nav_sample_rate == 20 and self.pixels == 2048:
-            from geotiepoints import metop20kmto1km
-            return metop20kmto1km(lons, lats)
-        else:
-            raise NotImplementedError("Lon/lat expansion not implemented for " +
-                                      "sample rate = " + str(nav_sample_rate) +
-                                      " and earth views = " +
-                                      str(self.pixels))
-
     def get_full_lonlats(self):
-        """Get the interpolated lons/lats."""
+        """Get the interpolated longitudes and latitudes."""
         if self.lons is not None and self.lats is not None:
             return self.lons, self.lats
 
@@ -210,25 +199,39 @@ class EPSAVHRRFile(BaseFileHandler):
         raw_lons = np.hstack((self["EARTH_LOCATION_FIRST"][:, [1]],
                               self["EARTH_LOCATIONS"][:, :, 1],
                               self["EARTH_LOCATION_LAST"][:, [1]]))
-        self.lons, self.lats = self._get_full_lonlats(raw_lons, raw_lats)
-        self.lons = da.from_delayed(self.lons, dtype=self["EARTH_LOCATIONS"].dtype,
-                                    shape=(self.scanlines, self.pixels))
-        self.lats = da.from_delayed(self.lats, dtype=self["EARTH_LOCATIONS"].dtype,
-                                    shape=(self.scanlines, self.pixels))
+        self.lons, self.lats = self._interpolate(raw_lons, raw_lats)
         return self.lons, self.lats
 
-    @delayed(nout=4, pure=True)
+    def _interpolate(self, lons_like, lats_like):
+        nav_sample_rate = self["NAV_SAMPLE_RATE"]
+        if nav_sample_rate == 20 and self.pixels == 2048:
+            lons_like_1km, lats_like_1km = self._interpolate_20km_to_1km(lons_like, lats_like)
+            lons_like_1km = da.from_delayed(lons_like_1km, dtype=lons_like.dtype,
+                                            shape=(self.scanlines, self.pixels))
+            lats_like_1km = da.from_delayed(lats_like_1km, dtype=lats_like.dtype,
+                                            shape=(self.scanlines, self.pixels))
+            return lons_like_1km, lats_like_1km
+        else:
+            raise NotImplementedError("Lon/lat and angle expansion not implemented for " +
+                                      "sample rate = " + str(nav_sample_rate) +
+                                      " and earth views = " +
+                                      str(self.pixels))
+
+    @delayed(nout=2, pure=True)
+    def _interpolate_20km_to_1km(self, lons, lats):
+        # Note: delayed will cast input dask-arrays to numpy arrays (needed by metop20kmto1km).
+        from geotiepoints import metop20kmto1km
+        return metop20kmto1km(lons, lats)
+
     def _get_full_angles(self, solar_zenith, sat_zenith, solar_azimuth, sat_azimuth):
 
         nav_sample_rate = self["NAV_SAMPLE_RATE"]
         if nav_sample_rate == 20 and self.pixels == 2048:
-            from geotiepoints import metop20kmto1km
-            # Note: interpolation asumes lat values values between -90 and 90
+            # Note: interpolation assumes second array values between -90 and 90
             # Solar and satellite zenith is between 0 and 180.
-            # Note: delayed will cast input dask-arrays to numpy arrays (needed by metop20kmto1km).
-            sun_azi, sun_zen = metop20kmto1km(solar_azimuth, solar_zenith - 90)
+            sun_azi, sun_zen = self._interpolate(solar_azimuth, solar_zenith - 90)
             sun_zen += 90
-            sat_azi, sat_zen = metop20kmto1km(sat_azimuth, sat_zenith - 90)
+            sat_azi, sat_zen = self._interpolate(sat_azimuth, sat_zenith - 90)
             sat_zen += 90
             return sun_azi, sun_zen, sat_azi, sat_zen
         else:
@@ -238,7 +241,7 @@ class EPSAVHRRFile(BaseFileHandler):
                                       str(self.pixels))
 
     def get_full_angles(self):
-        """Get the interpolated lons/lats."""
+        """Get the interpolated angles."""
         if (self.sun_azi is not None and self.sun_zen is not None and
                 self.sat_azi is not None and self.sat_zen is not None):
             return self.sun_azi, self.sun_zen, self.sat_azi, self.sat_zen
@@ -262,14 +265,6 @@ class EPSAVHRRFile(BaseFileHandler):
                                                                                        sat_zenith,
                                                                                        solar_azimuth,
                                                                                        sat_azimuth)
-        self.sun_azi = da.from_delayed(self.sun_azi, dtype=self["ANGULAR_RELATIONS"].dtype,
-                                       shape=(self.scanlines, self.pixels))
-        self.sun_zen = da.from_delayed(self.sun_zen, dtype=self["ANGULAR_RELATIONS"].dtype,
-                                       shape=(self.scanlines, self.pixels))
-        self.sat_azi = da.from_delayed(self.sat_azi, dtype=self["ANGULAR_RELATIONS"].dtype,
-                                       shape=(self.scanlines, self.pixels))
-        self.sat_zen = da.from_delayed(self.sat_zen, dtype=self["ANGULAR_RELATIONS"].dtype,
-                                       shape=(self.scanlines, self.pixels))
         return self.sun_azi, self.sun_zen, self.sat_azi, self.sat_zen
 
     def get_bounding_box(self):
@@ -291,59 +286,59 @@ class EPSAVHRRFile(BaseFileHandler):
         if self.sections is None:
             self._read_all()
 
-        if key.name in ['longitude', 'latitude']:
+        if key['name'] in ['longitude', 'latitude']:
             lons, lats = self.get_full_lonlats()
-            if key.name == 'longitude':
+            if key['name'] == 'longitude':
                 dataset = create_xarray(lons)
             else:
                 dataset = create_xarray(lats)
 
-        elif key.name in ['solar_zenith_angle', 'solar_azimuth_angle',
-                          'satellite_zenith_angle', 'satellite_azimuth_angle']:
+        elif key['name'] in ['solar_zenith_angle', 'solar_azimuth_angle',
+                             'satellite_zenith_angle', 'satellite_azimuth_angle']:
             sun_azi, sun_zen, sat_azi, sat_zen = self.get_full_angles()
-            if key.name == 'solar_zenith_angle':
+            if key['name'] == 'solar_zenith_angle':
                 dataset = create_xarray(sun_zen)
-            elif key.name == 'solar_azimuth_angle':
+            elif key['name'] == 'solar_azimuth_angle':
                 dataset = create_xarray(sun_azi)
-            if key.name == 'satellite_zenith_angle':
+            if key['name'] == 'satellite_zenith_angle':
                 dataset = create_xarray(sat_zen)
-            elif key.name == 'satellite_azimuth_angle':
+            elif key['name'] == 'satellite_azimuth_angle':
                 dataset = create_xarray(sat_azi)
         else:
             mask = None
-            if key.calibration == 'counts':
+            if key['calibration'] == 'counts':
                 raise ValueError('calibration=counts is not supported! ' +
                                  'This reader cannot return counts')
-            elif key.calibration not in ['reflectance', 'brightness_temperature', 'radiance']:
-                raise ValueError('calibration type ' + str(key.calibration) +
+            elif key['calibration'] not in ['reflectance', 'brightness_temperature', 'radiance']:
+                raise ValueError('calibration type ' + str(key['calibration']) +
                                  ' is not supported!')
 
-            if key.name in ['3A', '3a'] and self.three_a_mask is None:
+            if key['name'] in ['3A', '3a'] and self.three_a_mask is None:
                 self.three_a_mask = ((self["FRAME_INDICATOR"] & 2 ** 16) != 2 ** 16)
 
-            if key.name in ['3B', '3b'] and self.three_b_mask is None:
+            if key['name'] in ['3B', '3b'] and self.three_b_mask is None:
                 self.three_b_mask = ((self["FRAME_INDICATOR"] & 2 ** 16) != 0)
 
-            if key.name not in ["1", "2", "3a", "3A", "3b", "3B", "4", "5"]:
-                logger.info("Can't load channel in eps_l1b: " + str(key.name))
+            if key['name'] not in ["1", "2", "3a", "3A", "3b", "3B", "4", "5"]:
+                logger.info("Can't load channel in eps_l1b: " + str(key['name']))
                 return
 
-            if key.name == "1":
-                if key.calibration == 'reflectance':
+            if key['name'] == "1":
+                if key['calibration'] == 'reflectance':
                     array = radiance_to_refl(self["SCENE_RADIANCES"][:, 0, :],
                                              self["CH1_SOLAR_FILTERED_IRRADIANCE"])
                 else:
                     array = self["SCENE_RADIANCES"][:, 0, :]
 
-            if key.name == "2":
-                if key.calibration == 'reflectance':
+            if key['name'] == "2":
+                if key['calibration'] == 'reflectance':
                     array = radiance_to_refl(self["SCENE_RADIANCES"][:, 1, :],
                                              self["CH2_SOLAR_FILTERED_IRRADIANCE"])
                 else:
                     array = self["SCENE_RADIANCES"][:, 1, :]
 
-            if key.name.lower() == "3a":
-                if key.calibration == 'reflectance':
+            if key['name'].lower() == "3a":
+                if key['calibration'] == 'reflectance':
                     array = radiance_to_refl(self["SCENE_RADIANCES"][:, 2, :],
                                              self["CH3A_SOLAR_FILTERED_IRRADIANCE"])
                 else:
@@ -352,8 +347,8 @@ class EPSAVHRRFile(BaseFileHandler):
                 mask = np.empty(array.shape, dtype=bool)
                 mask[:, :] = self.three_a_mask[:, np.newaxis]
 
-            if key.name.lower() == "3b":
-                if key.calibration == 'brightness_temperature':
+            if key['name'].lower() == "3b":
+                if key['calibration'] == 'brightness_temperature':
                     array = radiance_to_bt(self["SCENE_RADIANCES"][:, 2, :],
                                            self["CH3B_CENTRAL_WAVENUMBER"],
                                            self["CH3B_CONSTANT1"],
@@ -363,8 +358,8 @@ class EPSAVHRRFile(BaseFileHandler):
                 mask = np.empty(array.shape, dtype=bool)
                 mask[:, :] = self.three_b_mask[:, np.newaxis]
 
-            if key.name == "4":
-                if key.calibration == 'brightness_temperature':
+            if key['name'] == "4":
+                if key['calibration'] == 'brightness_temperature':
                     array = radiance_to_bt(self["SCENE_RADIANCES"][:, 3, :],
                                            self["CH4_CENTRAL_WAVENUMBER"],
                                            self["CH4_CONSTANT1"],
@@ -372,8 +367,8 @@ class EPSAVHRRFile(BaseFileHandler):
                 else:
                     array = self["SCENE_RADIANCES"][:, 3, :]
 
-            if key.name == "5":
-                if key.calibration == 'brightness_temperature':
+            if key['name'] == "5":
+                if key['calibration'] == 'brightness_temperature':
                     array = radiance_to_bt(self["SCENE_RADIANCES"][:, 4, :],
                                            self["CH5_CENTRAL_WAVENUMBER"],
                                            self["CH5_CONSTANT1"],
