@@ -15,8 +15,8 @@
 #
 # You should have received a copy of the GNU General Public License along with
 # satpy.  If not, see <http://www.gnu.org/licenses/>.
-"""Reader for GOES 8-15 imager data in netCDF format from NOAA CLASS
-   Also handles GOES 15 data in netCDF format reformated by Eumetsat
+"""Reader for GOES 8-15 imager data in netCDF format from NOAA CLASS.
+Also handles GOES 15 data in netCDF format reformated by Eumetsat
 
 GOES Imager netCDF files contain geolocated detector counts. If ordering via
 NOAA CLASS, select 16 bits/pixel. The instrument oversamples the viewed scene
@@ -564,7 +564,8 @@ SCAN_DURATION = {
 
 
 class GOESNCBaseFileHandler(BaseFileHandler):
-    """File handler for GOES Imager data in netCDF format"""
+    """File handler for GOES Imager data in netCDF format."""
+
     def __init__(self, filename, filename_info, filetype_info, geo_data=None):
         """Initialize the reader."""
         super(GOESNCBaseFileHandler, self).__init__(filename, filename_info,
@@ -588,27 +589,29 @@ class GOESNCBaseFileHandler(BaseFileHandler):
 
     @abstractmethod
     def get_dataset(self, key, info):
-        """Load dataset designated by the given key from file"""
+        """Load dataset designated by the given key from file."""
         raise NotImplementedError
 
     @abstractmethod
     def calibrate(self, data, calibration, channel):
-        """Perform calibration"""
+        """Perform calibration."""
         raise NotImplementedError
 
     @property
     @abstractmethod
     def vis_sectors(self):
+        """Get the vis sectors."""
         raise NotImplementedError
 
     @property
     @abstractmethod
     def ir_sectors(self):
+        """Get the ir sectors."""
         raise NotImplementedError
 
     @staticmethod
     def _get_platform_name(ncattr):
-        """Determine name of the platform"""
+        """Determine name of the platform."""
         match = re.match(r'G-(\d+)', ncattr)
         if match:
             return SPACECRAFTS.get(int(match.groups()[0]))
@@ -616,7 +619,7 @@ class GOESNCBaseFileHandler(BaseFileHandler):
         return None
 
     def _get_sector(self, channel, nlines, ncols):
-        """Determine which sector was scanned"""
+        """Determine which sector was scanned."""
         if self._is_vis(channel):
             margin = 100
             sectors_ref = self.vis_sectors
@@ -633,7 +636,7 @@ class GOESNCBaseFileHandler(BaseFileHandler):
 
     @staticmethod
     def _is_vis(channel):
-        """Determine whether the given channel is a visible channel"""
+        """Determine whether the given channel is a visible channel."""
         if isinstance(channel, str):
             return channel == '00_7'
         elif isinstance(channel, int):
@@ -643,7 +646,7 @@ class GOESNCBaseFileHandler(BaseFileHandler):
 
     @staticmethod
     def _get_earth_mask(lat):
-        """Identify earth/space pixels
+        """Identify earth/space pixels.
 
         Returns:
             Mask (1=earth, 0=space)
@@ -653,7 +656,7 @@ class GOESNCBaseFileHandler(BaseFileHandler):
 
     @staticmethod
     def _get_nadir_pixel(earth_mask, sector):
-        """Find the nadir pixel
+        """Find the nadir pixel.
 
         Args:
             earth_mask: Mask identifying earth and space pixels
@@ -678,7 +681,7 @@ class GOESNCBaseFileHandler(BaseFileHandler):
 
     @staticmethod
     def _is_yaw_flip(lat, delta=10):
-        """Determine whether the satellite is yaw-flipped ('upside down')"""
+        """Determine whether the satellite is yaw-flipped ('upside down')."""
         logger.debug('Computing yaw flip flag')
         # In case of yaw-flip the data and coordinates in the netCDF files are
         # also flipped. Just check whether the latitude increases or decrases
@@ -687,7 +690,7 @@ class GOESNCBaseFileHandler(BaseFileHandler):
         return (lat[crow+delta, ccol] - lat[crow, ccol]).values > 0
 
     def _get_area_def_uniform_sampling(self, lon0, channel):
-        """Get area definition with uniform sampling"""
+        """Get area definition with uniform sampling."""
         logger.debug('Computing area definition')
 
         if lon0 is not None:
@@ -730,7 +733,7 @@ class GOESNCBaseFileHandler(BaseFileHandler):
 
     @property
     def start_time(self):
-        """Start timestamp of the dataset"""
+        """Start timestamp of the dataset."""
         dt = self.nc['time'].dt
         return datetime(year=dt.year, month=dt.month, day=dt.day,
                         hour=dt.hour, minute=dt.minute,
@@ -738,7 +741,7 @@ class GOESNCBaseFileHandler(BaseFileHandler):
 
     @property
     def end_time(self):
-        """End timestamp of the dataset"""
+        """End timestamp of the dataset."""
         try:
             return self.start_time + SCAN_DURATION[self.sector]
         except KeyError:
@@ -761,7 +764,7 @@ class GOESNCBaseFileHandler(BaseFileHandler):
         return 1000. * self.nc['lineRes'].values
 
     def get_shape(self, key, info):
-        """Get the shape of the data
+        """Get the shape of the data.
 
         Returns:
             Number of lines, number of columns
@@ -770,7 +773,7 @@ class GOESNCBaseFileHandler(BaseFileHandler):
 
     @property
     def meta(self):
-        """Derive metadata from the coordinates"""
+        """Derive metadata from the coordinates."""
         # Use buffered data if available
         if self._meta is None:
             lat = self.geo_data['lat']
@@ -797,7 +800,7 @@ class GOESNCBaseFileHandler(BaseFileHandler):
         return self._meta
 
     def _counts2radiance(self, counts, coefs, channel):
-        """Convert raw detector counts to radiance"""
+        """Convert raw detector counts to radiance."""
         logger.debug('Converting counts to radiance')
 
         if self._is_vis(channel):
@@ -812,7 +815,7 @@ class GOESNCBaseFileHandler(BaseFileHandler):
                                        offset=coefs['offset'])
 
     def _calibrate(self, radiance, coefs, channel, calibration):
-        """Convert radiance to reflectance or brightness temperature"""
+        """Convert radiance to reflectance or brightness temperature."""
         if self._is_vis(channel):
             if not calibration == 'reflectance':
                 raise ValueError('Cannot calibrate VIS channel to '
@@ -834,7 +837,7 @@ class GOESNCBaseFileHandler(BaseFileHandler):
 
     @staticmethod
     def _ircounts2radiance(counts, scale, offset):
-        """Convert IR counts to radiance
+        """Convert IR counts to radiance.
 
         Reference: [IR].
 
@@ -851,7 +854,7 @@ class GOESNCBaseFileHandler(BaseFileHandler):
 
     @staticmethod
     def _calibrate_ir(radiance, coefs):
-        """Convert IR radiance to brightness temperature
+        """Convert IR radiance to brightness temperature.
 
         Reference: [IR]
 
@@ -880,7 +883,7 @@ class GOESNCBaseFileHandler(BaseFileHandler):
 
     @staticmethod
     def _viscounts2radiance(counts, slope, offset):
-        """Convert VIS counts to radiance
+        """Convert VIS counts to radiance.
 
         References: [VIS]
 
@@ -896,7 +899,7 @@ class GOESNCBaseFileHandler(BaseFileHandler):
 
     @staticmethod
     def _calibrate_vis(radiance, k):
-        """Convert VIS radiance to reflectance
+        """Convert VIS radiance to reflectance.
 
         Note: Angle of incident radiation and annual variation of the
         earth-sun distance is not taken into account. A value of 100%
@@ -922,7 +925,7 @@ class GOESNCBaseFileHandler(BaseFileHandler):
         return refl.clip(min=0)
 
     def _update_metadata(self, data, ds_info):
-        """Update metadata of the given DataArray"""
+        """Update metadata of the given DataArray."""
         # Metadata from the dataset definition
         data.attrs.update(ds_info)
 
@@ -957,6 +960,7 @@ class GOESNCBaseFileHandler(BaseFileHandler):
             )
 
     def __del__(self):
+        """Delete."""
         try:
             self.nc.close()
         except (AttributeError, IOError, OSError):
@@ -973,7 +977,6 @@ class GOESNCBaseFileHandler(BaseFileHandler):
         See
         :meth:`satpy.readers.file_handlers.BaseFileHandler.available_datasets`
         for details.
-
         """
         res = self.resolution
         # update previously configured datasets
@@ -991,7 +994,7 @@ class GOESNCBaseFileHandler(BaseFileHandler):
 
 
 class GOESNCFileHandler(GOESNCBaseFileHandler):
-    """File handler for GOES Imager data in netCDF format"""
+    """File handler for GOES Imager data in netCDF format."""
 
     vis_sectors = VIS_SECTORS
     ir_sectors = IR_SECTORS
@@ -1002,19 +1005,19 @@ class GOESNCFileHandler(GOESNCBaseFileHandler):
                                                 filetype_info)
 
     def get_dataset(self, key, info):
-        """Load dataset designated by the given key from file"""
-        logger.debug('Reading dataset {}'.format(key.name))
+        """Load dataset designated by the given key from file."""
+        logger.debug('Reading dataset {}'.format(key['name']))
 
         # Read data from file and calibrate if necessary
-        if 'longitude' in key.name:
+        if 'longitude' in key['name']:
             data = self.geo_data['lon']
-        elif 'latitude' in key.name:
+        elif 'latitude' in key['name']:
             data = self.geo_data['lat']
         else:
             tic = datetime.now()
             data = self.calibrate(self.nc['data'].isel(time=0),
-                                  calibration=key.calibration,
-                                  channel=key.name)
+                                  calibration=key['calibration'],
+                                  channel=key['name'])
             logger.debug('Calibration time: {}'.format(datetime.now() - tic))
 
         # Mask space pixels
@@ -1029,7 +1032,7 @@ class GOESNCFileHandler(GOESNCBaseFileHandler):
         return data
 
     def calibrate(self, counts, calibration, channel):
-        """Perform calibration"""
+        """Perform calibration."""
         # Convert 16bit counts from netCDF4 file to the original 10bit
         # GVAR counts by dividing by 32. See [FAQ].
         counts = counts / 32.
@@ -1052,7 +1055,7 @@ class GOESNCFileHandler(GOESNCBaseFileHandler):
 
 
 class GOESEUMNCFileHandler(GOESNCBaseFileHandler):
-    """File handler for GOES Imager data in EUM netCDF format
+    """File handler for GOES Imager data in EUM netCDF format.
 
     TODO: Remove datasets which are not available in the file (counts,
     VIS radiance) via available_datasets()  -> See #434
@@ -1067,13 +1070,13 @@ class GOESEUMNCFileHandler(GOESNCBaseFileHandler):
                                                    filetype_info, geo_data)
 
     def get_dataset(self, key, info):
-        """Load dataset designated by the given key from file"""
-        logger.debug('Reading dataset {}'.format(key.name))
+        """Load dataset designated by the given key from file."""
+        logger.debug('Reading dataset {}'.format(key['name']))
 
         tic = datetime.now()
         data = self.calibrate(self.nc['data'].isel(time=0),
-                              calibration=key.calibration,
-                              channel=key.name)
+                              calibration=key['calibration'],
+                              channel=key['name'])
         logger.debug('Calibration time: {}'.format(datetime.now() - tic))
 
         # Mask space pixels
@@ -1089,7 +1092,7 @@ class GOESEUMNCFileHandler(GOESNCBaseFileHandler):
         return data
 
     def calibrate(self, data, calibration, channel):
-        """Perform calibration"""
+        """Perform calibration."""
         coefs = CALIB_COEFS[self.platform_name][channel]
         is_vis = self._is_vis(channel)
 
@@ -1107,7 +1110,8 @@ class GOESEUMNCFileHandler(GOESNCBaseFileHandler):
 
 
 class GOESEUMGEONCFileHandler(BaseFileHandler):
-    """File handler for GOES Geolocation data in EUM netCDF format"""
+    """File handler for GOES Geolocation data in EUM netCDF format."""
+
     def __init__(self, filename, filename_info, filetype_info):
         """Initialize the reader."""
         super(GOESEUMGEONCFileHandler, self).__init__(filename, filename_info,
@@ -1125,19 +1129,20 @@ class GOESEUMGEONCFileHandler(BaseFileHandler):
         self._meta = None
 
     def __getitem__(self, item):
+        """Get item."""
         return getattr(self.nc, item)
 
     def get_dataset(self, key, info):
-        """Load dataset designated by the given key from file"""
-        logger.debug('Reading dataset {}'.format(key.name))
+        """Load dataset designated by the given key from file."""
+        logger.debug('Reading dataset {}'.format(key['name']))
 
         # Read data from file and calibrate if necessary
-        if 'longitude' in key.name:
+        if 'longitude' in key['name']:
             data = self.nc['lon']
-        elif 'latitude' in key.name:
+        elif 'latitude' in key['name']:
             data = self.nc['lat']
         else:
-            raise KeyError("Unknown dataset: {}".format(key.name))
+            raise KeyError("Unknown dataset: {}".format(key['name']))
 
         # Set proper dimension names
         data = data.rename({'xc': 'x', 'yc': 'y'})
@@ -1156,7 +1161,7 @@ class GOESEUMGEONCFileHandler(BaseFileHandler):
 
 
 class GOESCoefficientReader(object):
-    """Read GOES Imager calibration coefficients from NOAA reference HTMLs"""
+    """Read GOES Imager calibration coefficients from NOAA reference HTMLs."""
 
     gvar_channels = {
         'GOES-8': {'00_7': 1, '03_9': 2, '06_8': 3, '10_7': 4, '12_0': 5},
@@ -1192,6 +1197,7 @@ class GOESCoefficientReader(object):
     }
 
     def __init__(self, ir_url, vis_url):
+        """Init the coef reader."""
         from bs4 import BeautifulSoup
         self.ir_html = BeautifulSoup(self._load_url_or_file(ir_url),
                                      features="html5lib")
@@ -1216,6 +1222,7 @@ class GOESCoefficientReader(object):
                 raise ValueError('Invalid URL or file: {}'.format(url))
 
     def get_coefs(self, platform, channel):
+        """Get the coefs."""
         if channel == '00_7':
             return self._get_vis_coefs(platform=platform)
 
@@ -1308,7 +1315,7 @@ class GOESCoefficientReader(object):
         return string.replace('\n', '').replace(' ', '')
 
     def _float(self, string):
-        """Convert string to float
+        """Convert string to float.
 
         Take care of numbers in exponential format
         """
@@ -1325,7 +1332,7 @@ class GOESCoefficientReader(object):
 
 
 def test_coefs(ir_url, vis_url):
-    """Test calibration coefficients against NOAA reference pages
+    """Test calibration coefficients against NOAA reference pages.
 
     Currently the reference pages are:
 
