@@ -39,8 +39,10 @@ logger = logging.getLogger(__name__)
 
 
 class MAIAFileHandler(BaseFileHandler):
+    """File handler for Maia files."""
 
     def __init__(self, filename, filename_info, filetype_info):
+        """Init the file handler."""
         super(MAIAFileHandler, self).__init__(
             filename, filename_info, filetype_info)
         self.finfo = filename_info
@@ -57,6 +59,7 @@ class MAIAFileHandler(BaseFileHandler):
         self.read(self.filename)
 
     def read(self, filename):
+        """Read the file."""
         self.h5 = h5py.File(filename, 'r')
         missing = -9999.
         self.Lat = da.from_array(self.h5[u'DATA/Latitude'], chunks=CHUNK_SIZE) / 10000.
@@ -105,6 +108,7 @@ class MAIAFileHandler(BaseFileHandler):
         self.file_content['ct'] = classif.astype(np.uint8)
 
     def get_platform(self, platform):
+        """Get the platform."""
         if self.file_content['sat_id'] in (14,):
             return "viirs"
         else:
@@ -112,26 +116,27 @@ class MAIAFileHandler(BaseFileHandler):
 
     @property
     def start_time(self):
+        """Get the start time."""
         return self.finfo['start_time']
 
     @property
     def end_time(self):
+        """Get the end time."""
         return self.finfo['end_time']
 
     def get_dataset(self, key, info, out=None):
         """Get a dataset from the file."""
-
-        logger.debug("Reading %s.", key.name)
-        values = self.file_content[key.name]
+        logger.debug("Reading %s.", key['name'])
+        values = self.file_content[key['name']]
         selected = np.array(self.selected)
-        if key.name in ("Latitude", "Longitude"):
+        if key['name'] in ("Latitude", "Longitude"):
             values = values / 10000.
-        if key.name in ('Tsurf', 'CloudTopPres', 'CloudTopTemp'):
+        if key['name'] in ('Tsurf', 'CloudTopPres', 'CloudTopTemp'):
             goods = values > -9998.
             selected = np.array(selected & goods)
-            if key.name in ('Tsurf', "Alt_surface", "CloudTopTemp"):
+            if key['name'] in ('Tsurf', "Alt_surface", "CloudTopTemp"):
                 values = values / 100.
-            if key.name in ("CloudTopPres"):
+            if key['name'] in ("CloudTopPres"):
                 values = values / 10.
         else:
             selected = self.selected
@@ -139,7 +144,7 @@ class MAIAFileHandler(BaseFileHandler):
 
         fill_value = np.nan
 
-        if key.name == 'ct':
+        if key['name'] == 'ct':
             fill_value = 0
             info['_FillValue'] = 0
         ds = DataArray(values, dims=['y', 'x'], attrs=info).where(selected, fill_value)
