@@ -35,6 +35,7 @@ onboard Joint Polar Satellite System spacecraft.
 
 from datetime import datetime
 import xarray as xr
+import pandas as pd
 import numpy as np
 import logging
 from collections import defaultdict
@@ -81,7 +82,7 @@ class NUCAPSFileHandler(NetCDF4FileHandler):
 
     def _parse_datetime(self, datestr):
         """Parse NUCAPS datetime string."""
-        return datetime.strptime(datestr, "%Y-%m-%dT%H:%M:%S.%fZ")
+        return pd.to_datetime(datestr).to_pydatetime()
 
     @property
     def start_time(self):
