@@ -15,9 +15,14 @@
 #
 # You should have received a copy of the GNU General Public License along with
 # satpy.  If not, see <http://www.gnu.org/licenses/>.
-"""SEVIRI L2 BUFR format reader."""
 
+"""SEVIRI L2 BUFR format reader.
 
+References:
+    EUMETSAT Product Navigator
+    https://navigator.eumetsat.int/
+
+"""
 import logging
 from datetime import timedelta, datetime
 import numpy as np
@@ -97,7 +102,7 @@ class SeviriL2BufrFileHandler(BaseFileHandler):
         return recarray2dict(hdr)
 
     def get_attribute(self, key):
-        ''' Get BUFR attributes '''
+        """Get BUFR attributes."""
         # This function is inefficient as it is looping through the entire
         # file to get 1 attribute. It causes a problem though if you break
         # from the file early - dont know why but investigating - fix later
