@@ -151,8 +151,8 @@ class VIIRSCompactFileHandler(BaseFileHandler):
 
     def get_dataset(self, key, info):
         """Load a dataset."""
-        logger.debug('Reading %s.', key.name)
-        if key.name in chans_dict:
+        logger.debug('Reading %s.', key['name'])
+        if key['name'] in chans_dict:
             m_data = self.read_dataset(key, info)
         else:
             m_data = self.read_geo(key, info)
@@ -201,16 +201,16 @@ class VIIRSCompactFileHandler(BaseFileHandler):
         if self.lons is None or self.lats is None:
             self.lons, self.lats = self.navigate()
         for pair, fkeys in pairs.items():
-            if key.name in pair:
+            if key['name'] in pair:
                 if (self.cache.get(pair[0]) is None
                         or self.cache.get(pair[1]) is None):
                     angles = self.angles(*fkeys)
                     self.cache[pair[0]], self.cache[pair[1]] = angles
-                if key.name == pair[0]:
-                    return xr.DataArray(self.cache[pair[0]], name=key.name,
+                if key['name'] == pair[0]:
+                    return xr.DataArray(self.cache[pair[0]], name=key['name'],
                                         attrs=self.mda, dims=('y', 'x'))
                 else:
-                    return xr.DataArray(self.cache[pair[1]], name=key.name,
+                    return xr.DataArray(self.cache[pair[1]], name=key['name'],
                                         attrs=self.mda, dims=('y', 'x'))
 
         if info.get('standard_name') in ['latitude', 'longitude']:
@@ -223,7 +223,7 @@ class VIIRSCompactFileHandler(BaseFileHandler):
             else:
                 return xr.DataArray(self.lats, attrs=mda, dims=('y', 'x'))
 
-        if key.name == 'dnb_moon_illumination_fraction':
+        if key['name'] == 'dnb_moon_illumination_fraction':
             mda = self.mda.copy()
             mda.update(info)
             return xr.DataArray(da.from_array(self.geostuff["MoonIllumFraction"]),
@@ -232,7 +232,7 @@ class VIIRSCompactFileHandler(BaseFileHandler):
     def read_dataset(self, dataset_key, info):
         """Read a dataset."""
         h5f = self.h5f
-        channel = chans_dict[dataset_key.name]
+        channel = chans_dict[dataset_key['name']]
         chan_dict = dict([(key.split("-")[1], key)
                           for key in h5f["All_Data"].keys()
                           if key.startswith("VIIRS")])
@@ -240,7 +240,7 @@ class VIIRSCompactFileHandler(BaseFileHandler):
         h5rads = h5f["All_Data"][chan_dict[channel]]["Radiance"]
         chunks = h5rads.chunks or CHUNK_SIZE
         rads = xr.DataArray(da.from_array(h5rads, chunks=chunks),
-                            name=dataset_key.name,
+                            name=dataset_key['name'],
                             dims=['y', 'x']).astype(np.float32)
         h5attrs = h5rads.attrs
         scans = h5f["All_Data"]["NumberOfScans"][0]
@@ -263,9 +263,9 @@ class VIIRSCompactFileHandler(BaseFileHandler):
             logger.info("Missing attribute for scaling of %s.", channel)
             pass
         unit = "W m-2 sr-1 μm-1"
-        if dataset_key.calibration == 'counts':
+        if dataset_key['calibration'] == 'counts':
             raise NotImplementedError("Can't get counts from this data")
-        if dataset_key.calibration in ['reflectance', 'brightness_temperature']:
+        if dataset_key['calibration'] in ['reflectance', 'brightness_temperature']:
             # do calibrate
             try:
                 # First guess: VIS or NIR data
@@ -291,7 +291,7 @@ class VIIRSCompactFileHandler(BaseFileHandler):
                 except KeyError:
                     logger.warning("Calibration failed.")
 
-        elif dataset_key.calibration != 'radiance':
+        elif dataset_key['calibration'] != 'radiance':
             raise ValueError("Calibration parameter should be radiance, "
                              "reflectance or brightness_temperature")
         rads = rads.clip(min=0)
