@@ -67,7 +67,7 @@ class VIIRSEDRFlood(HDF4FileHandler):
 
     def get_dataset(self, ds_id, ds_info):
         """Get dataset."""
-        data = self[ds_id.name]
+        data = self[ds_id['name']]
 
         data.attrs = self.get_metadata(data, ds_info)
 
@@ -84,7 +84,7 @@ class VIIRSEDRFlood(HDF4FileHandler):
 
     def get_area_def(self, ds_id):
         """Get area definition."""
-        data = self[ds_id.name]
+        data = self[ds_id['name']]
 
         proj_dict = {
             'proj': 'latlong',
