@@ -73,7 +73,7 @@ class FakeHDF5FileHandler2(FakeHDF5FileHandler):
                                     'Slope': 1., 'Intercept': 0.,
                                     'FillValue': 0,
                                     'units': 'NUL',
-                                    'band_names': 'NUL'.format(ch).encode('utf-8'),
+                                    'band_names': 'NUL',
                                     'long_name': b'Calibration coefficient (SCALE and OFFSET)',
                                     'valid_range': [-500, 500],
                                 },
@@ -86,7 +86,7 @@ class FakeHDF5FileHandler2(FakeHDF5FileHandler):
                                     'Slope': 1., 'Intercept': 0.,
                                     'FillValue': 0,
                                     'units': 'NUL',
-                                    'band_names': 'NUL'.format(ch).encode('utf-8'),
+                                    'band_names': 'NUL',
                                     'long_name': b'Calibration coefficient (SCALE and OFFSET)',
                                     'valid_range': [-500, 500],
                                 },
@@ -99,7 +99,7 @@ class FakeHDF5FileHandler2(FakeHDF5FileHandler):
                                     'Slope': 1., 'Intercept': 0.,
                                     'FillValue': 0,
                                     'units': 'NUL',
-                                    'band_names': 'NUL'.format(ch).encode('utf-8'),
+                                    'band_names': 'NUL',
                                     'long_name': b'Calibration coefficient (SCALE and OFFSET)',
                                     'valid_range': [-500, 500],
                                 },
@@ -113,7 +113,7 @@ class FakeHDF5FileHandler2(FakeHDF5FileHandler):
                                     'Slope': 1., 'Intercept': 0.,
                                     'FillValue': 0,
                                     'units': 'NUL',
-                                    'band_names': 'NUL'.format(ch).encode('utf-8'),
+                                    'band_names': 'NUL',
                                     'long_name': b'Calibration coefficient (SCALE and OFFSET)',
                                     'valid_range': [-500, 500],
                                 },
