@@ -18,21 +18,20 @@
 """The HRIT electrol reader tests package."""
 
 import datetime
-import numpy as np
-import dask.array as da
-from xarray import DataArray
-
-from satpy.readers.electrol_hrit import (recarray2dict, prologue,
-                                         HRITGOMSPrologueFileHandler,
-                                         HRITGOMSEpilogueFileHandler,
-                                         HRITGOMSFileHandler,
-                                         satellite_status,
-                                         image_acquisition,
-                                         epilogue)
-
 import unittest
 from unittest import mock
 
+import dask.array as da
+import numpy as np
+from xarray import DataArray
+
+from satpy.readers.electrol_hrit import (HRITGOMSEpilogueFileHandler,
+                                         HRITGOMSFileHandler,
+                                         HRITGOMSPrologueFileHandler, epilogue,
+                                         image_acquisition, prologue,
+                                         recarray2dict, satellite_status)
+from satpy.tests.utils import make_dataid
+
 # Simplify some type selections
 f64_t = np.float64
 i32_t = np.int32
@@ -41,7 +40,9 @@ u32_t = np.uint32
 
 class Testrecarray2dict(unittest.TestCase):
     """Test the function that converts numpy record arrays into dicts for use within SatPy."""
+
     def test_fun(self):
+        """Test record array."""
         inner_st = np.dtype([('test_str', '<S20'), ('test_int', 'i4')])
         outer_st = np.dtype([('test_sec', inner_st), ('test_flt', 'f4')])
 
@@ -56,6 +57,7 @@ class Testrecarray2dict(unittest.TestCase):
 
 class TestHRITGOMSProFileHandler(unittest.TestCase):
     """Test the HRIT Prologue FileHandler."""
+
     # Below are variable definitions used in testing the prologue reader.
     # These values are taken from a typical ELECTRO-L HRIT scene
     test_sat_status = {'TagType': 2,
@@ -81,7 +83,7 @@ class TestHRITGOMSProFileHandler(unittest.TestCase):
     @mock.patch('satpy.readers.electrol_hrit.np.fromfile')
     @mock.patch('satpy.readers.electrol_hrit.HRITFileHandler.__init__')
     def test_init(self, new_fh_init, fromfile):
-        """Setup the hrit file handler for testing."""
+        """Set up the hrit file handler for testing."""
         new_fh_init.return_value.filename = 'filename'
         HRITGOMSPrologueFileHandler.filename = 'filename'
         HRITGOMSPrologueFileHandler.mda = {'total_header_length': 1}
@@ -120,12 +122,12 @@ class TestHRITGOMSProFileHandler(unittest.TestCase):
 
 
 class TestHRITGOMSEpiFileHandler(unittest.TestCase):
-    '''Test the HRIT Epilogue FileHandler.'''
+    """Test the HRIT Epilogue FileHandler."""
 
     @mock.patch('satpy.readers.electrol_hrit.np.fromfile')
     @mock.patch('satpy.readers.electrol_hrit.HRITFileHandler.__init__')
     def test_init(self, new_fh_init, fromfile):
-        """Setup the hrit file handler for testing."""
+        """Set up the hrit file handler for testing."""
         new_fh_init.return_value.filename = 'filename'
         HRITGOMSEpilogueFileHandler.filename = 'filename'
         HRITGOMSEpilogueFileHandler.mda = {'total_header_length': 1}
@@ -158,27 +160,27 @@ class TestHRITGOMSEpiFileHandler(unittest.TestCase):
                 epi['GeometricProcessing']['TimeProcessing'], np.ones(10))
 
 
-class resser:
-    attrs = {}
-    calibration = 'counts'
-
-
 @mock.patch('satpy.readers.electrol_hrit.HRITGOMSFileHandler.__init__', return_value=None)
 @mock.patch('satpy.readers.electrol_hrit.HRITFileHandler.get_dataset', return_value={})
 class TestHRITGOMSFileHandler(unittest.TestCase):
-    '''A test of the ELECTRO-L main file handler functions'''
+    """A test of the ELECTRO-L main file handler functions."""
 
-    @mock.patch('satpy.readers.electrol_hrit.HRITGOMSFileHandler.calibrate', return_value=resser())
-    def test_get_dataset(self, *mocks):
+    @mock.patch('satpy.readers.electrol_hrit.HRITGOMSFileHandler.calibrate')
+    def test_get_dataset(self, calibrate_mock, *mocks):
+        """Test get dataset."""
+        key = make_dataid(name='CH1', calibration='counts')
+        fake_array = mock.MagicMock()
+        fake_array.attrs = dict()
+        calibrate_mock.return_value = fake_array
         fh = HRITGOMSFileHandler()
         fh.platform_name = 'Electro'
         fh.mda = {'projection_parameters': {'SSP_longitude': 0.0},
                   'orbital_parameters': {'satellite_nominal_longitude': 0.5}}
         info = {'units': 'm', 'standard_name': 'electro', 'wavelength': 5.0}
-        output = fh.get_dataset(resser(), info)
+        output = fh.get_dataset(key, info)
 
         # Check that 'calibrate' is called
-        mocks[1].assert_called()
+        calibrate_mock.assert_called()
 
         # Check that the correct attributes are returned
         attrs_exp = info.copy()
@@ -189,9 +191,10 @@ class TestHRITGOMSFileHandler(unittest.TestCase):
                                                  'projection_altitude': 35785831.00},
                           'platform_name': 'Electro',
                           'sensor': 'msu-gs'})
-        self.assertDictContainsSubset(attrs_exp, output.attrs)
+        assert dict(output.attrs, **attrs_exp) == output.attrs
 
     def test_calibrate(self, *mocks):
+        """Test calibrate."""
         lut = np.linspace(1e6, 1.6e6, num=1024).astype(np.int32)
         lut = np.tile(lut, (10, 1))
         fh = HRITGOMSFileHandler()
@@ -220,7 +223,7 @@ class TestHRITGOMSFileHandler(unittest.TestCase):
         self.assertTrue(np.allclose(out.values, lut[0, counts]/1000.))
 
     def test_get_area_def(self, *mocks):
-
+        """Test get_area_def."""
         example_area_ext = (-5566748.0802, -1854249.1809,
                             5570748.6178, 2000.2688)
 
