@@ -149,21 +149,14 @@ class FakeNetCDF4FileHandler2(FakeNetCDF4FileHandler):
 
     def _get_test_content_areadef(self):
         data = {}
-        proc = "state/processor"
-        for (lb, no) in (
-                ("earth_equatorial_radius", 6378137),
-                ("earth_polar_radius", 6356752),
-                ("reference_altitude", 35786000),
-                ("projection_origin_longitude", 0)):
-            data[proc + "/" + lb] = xr.DataArray(no)
+
         proj = "data/mtg_geos_projection"
 
         attrs = {
-                "sweep_angle_axis": "x",
-                "perspective_point_height": "35786400",
-                "semi_major_axis": "6378137",
-                "semi_minor_axis": "6356752",
-                "longitude_of_projection_origin": "0",
+                "sweep_angle_axis": "y",
+                "perspective_point_height": "35786400.0",
+                "semi_major_axis": "6378137.0",
+                "longitude_of_projection_origin": "0.0",
                 "inverse_flattening": "298.257223563",
                 "units": "m"}
         data[proj] = xr.DataArray(
@@ -256,9 +249,6 @@ class TestFCIL1CFDHSIReader:
 class TestFCIL1CFDHSIReaderGoodData(TestFCIL1CFDHSIReader):
     """Test FCI L1C FDHSI reader."""
 
-    # TODO:
-    # - test geolocation
-
     _alt_handler = FakeNetCDF4FileHandler2
 
     def test_file_pattern(self, reader_configs):
@@ -483,6 +473,39 @@ class TestFCIL1CFDHSIReaderGoodData(TestFCIL1CFDHSIReader):
                     make_dataid(name="ir_123", calibration="unknown"),
                     {"units": "unknown"})
 
+    def test_area_definition_computation(self, reader_configs):
+        """Test that the geolocation computation is correct."""
+        from satpy.readers import load_reader
+
+        filenames = [
+            "W_XX-EUMETSAT-Darmstadt,IMG+SAT,MTI1+FCI-1C-RRAD-FDHSI-FD--"
+            "CHK-BODY--L2P-NC4E_C_EUMT_20170410114434_GTT_DEV_"
+            "20170410113925_20170410113934_N__C_0070_0067.nc",
+        ]
+
+        reader = load_reader(reader_configs)
+        loadables = reader.select_files_from_pathnames(filenames)
+        reader.create_filehandlers(loadables)
+        res = reader.load(['ir_105', 'vis_06'], pad_data=False)
+
+        # test that area_ids are harmonisation-conform <platform>_<instrument>_<service>_<resolution>
+        assert res['vis_06'].attrs['area'].area_id == 'mtg_fci_fdss_1km'
+        assert res['ir_105'].attrs['area'].area_id == 'mtg_fci_fdss_2km'
+
+        area_def = res['ir_105'].attrs['area']
+        # test area extents computation
+        np.testing.assert_array_almost_equal(np.array(area_def.area_extent),
+                                             np.array([-5568062.23065902, 5168057.7600648,
+                                                       16704186.692027, 5568062.23065902]))
+
+        # check that the projection is read in properly
+        assert area_def.crs.coordinate_operation.method_name == 'Geostationary Satellite (Sweep Y)'
+        assert area_def.crs.coordinate_operation.params[0].value == 0.0  # projection origin longitude
+        assert area_def.crs.coordinate_operation.params[1].value == 35786400.0  # projection height
+        assert area_def.crs.ellipsoid.semi_major_metre == 6378137.0
+        assert area_def.crs.ellipsoid.inverse_flattening == 298.257223563
+        assert area_def.crs.ellipsoid.is_semi_minor_computed
+
 
 class TestFCIL1CFDHSIReaderBadData(TestFCIL1CFDHSIReader):
     """Test the FCI L1C FDHSI Reader for bad data input."""
