@@ -18,7 +18,7 @@
 """Module for testing the satpy.readers.hdf4_utils module."""
 
 import os
-import sys
+import unittest
 import numpy as np
 import xarray as xr
 
@@ -28,11 +28,6 @@ except ImportError:
     # fake the import so we can at least run the tests in this file
     HDF4FileHandler = object
 
-if sys.version_info < (2, 7):
-    import unittest2 as unittest
-else:
-    import unittest
-
 
 class FakeHDF4FileHandler(HDF4FileHandler):
     """Swap-in NetCDF4 File Handler for reader tests to use."""
@@ -123,12 +118,3 @@ class TestHDF4FileHandler(unittest.TestCase):
 
         self.assertTrue('ds1_f' in file_handler)
         self.assertFalse('fake_ds' in file_handler)
-
-
-def suite():
-    """Create the test suite for test_hdf4_utils."""
-    loader = unittest.TestLoader()
-    mysuite = unittest.TestSuite()
-    mysuite.addTest(loader.loadTestsFromTestCase(TestHDF4FileHandler))
-
-    return mysuite
