@@ -15,33 +15,24 @@
 #
 # You should have received a copy of the GNU General Public License along with
 # satpy.  If not, see <http://www.gnu.org/licenses/>.
-"""The HRIT base reader tests package.
-"""
+"""The HRIT base reader tests package."""
 
-import sys
-from datetime import datetime
 import os
+import unittest
+from unittest import mock
+from datetime import datetime
 from tempfile import gettempdir, NamedTemporaryFile
 
 import numpy as np
 
 from satpy.readers.hrit_base import HRITFileHandler, get_xritdecompress_cmd, get_xritdecompress_outfile, decompress
 
-if sys.version_info < (2, 7):
-    import unittest2 as unittest
-else:
-    import unittest
-
-try:
-    from unittest import mock
-except ImportError:
-    import mock
-
 
 class TestHRITDecompress(unittest.TestCase):
     """Test the on-the-fly decompression."""
 
     def test_xrit_cmd(self):
+        """Test running the xrit decompress command."""
         old_env = os.environ.get('XRIT_DECOMPRESS_PATH', None)
 
         os.environ['XRIT_DECOMPRESS_PATH'] = '/path/to/my/bin'
@@ -63,13 +54,14 @@ class TestHRITDecompress(unittest.TestCase):
         self.assertEqual(fname, res)
 
     def test_xrit_outfile(self):
+        """Test the right decompression filename is used."""
         stdout = [b"Decompressed file: bla.__\n"]
         outfile = get_xritdecompress_outfile(stdout)
         self.assertEqual(outfile, b'bla.__')
 
     @mock.patch('satpy.readers.hrit_base.Popen')
     def test_decompress(self, popen):
-
+        """Test decompression works."""
         popen.return_value.returncode = 0
         popen.return_value.communicate.return_value = [b"Decompressed file: bla.__\n"]
 
@@ -92,7 +84,7 @@ class TestHRITFileHandler(unittest.TestCase):
 
     @mock.patch('satpy.readers.hrit_base.np.fromfile')
     def setUp(self, fromfile):
-        """Setup the hrit file handler for testing."""
+        """Set up the hrit file handler for testing."""
         m = mock.mock_open()
         fromfile.return_value = np.array([(1, 2)], dtype=[('total_header_length', int),
                                                           ('hdr_id', int)])
@@ -135,16 +127,20 @@ class TestHRITFileHandler(unittest.TestCase):
         self.assertEqual(131072, y__)
 
     def test_get_area_extent(self):
+        """Test getting the area extent."""
         res = self.reader.get_area_extent((20, 20), (10, 10), (5, 5), 33)
         exp = (-71717.44995740513, -71717.44995740513,
                79266.655216079365, 79266.655216079365)
         self.assertTupleEqual(res, exp)
 
     def test_get_area_def(self):
+        """Test getting an area definition."""
+        from pyresample.utils import proj4_radius_parameters
         area = self.reader.get_area_def('VIS06')
         proj_dict = area.proj_dict
-        self.assertEqual(proj_dict['a'], 6378169.0)
-        self.assertEqual(proj_dict['b'], 6356583.8)
+        a, b = proj4_radius_parameters(proj_dict)
+        self.assertEqual(a, 6378169.0)
+        self.assertEqual(b, 6356583.8)
         self.assertEqual(proj_dict['h'], 35785831.0)
         self.assertEqual(proj_dict['lon_0'], 44.0)
         self.assertEqual(proj_dict['proj'], 'geos')
@@ -155,24 +151,10 @@ class TestHRITFileHandler(unittest.TestCase):
 
     @mock.patch('satpy.readers.hrit_base.np.memmap')
     def test_read_band(self, memmap):
+        """Test reading a single band."""
         nbits = self.reader.mda['number_of_bits_per_pixel']
         memmap.return_value = np.random.randint(0, 256,
                                                 size=int((464 * 3712 * nbits) / 8),
                                                 dtype=np.uint8)
         res = self.reader.read_band('VIS006', None)
         self.assertEqual(res.compute().shape, (464, 3712))
-
-
-def suite():
-    """The test suite for test_scene.
-    """
-    loader = unittest.TestLoader()
-    mysuite = unittest.TestSuite()
-    mysuite.addTest(loader.loadTestsFromTestCase(TestHRITFileHandler))
-    mysuite.addTest(loader.loadTestsFromTestCase(TestHRITDecompress))
-
-    return mysuite
-
-
-if __name__ == '__main__':
-    unittest.main()
