@@ -18,15 +18,20 @@
 """Module for testing the satpy.readers.grib module."""
 
 import sys
-import numpy as np
 import unittest
-from unittest import mock
 from datetime import datetime
+from unittest import mock
+
+import numpy as np
+
+from satpy.tests.utils import make_dataid
 
 
 class FakeMessage(object):
     """Fake message returned by pygrib.open().message(x)."""
+
     def __init__(self, values, proj_params=None, latlons=None, **attrs):
+        """Init the fake message."""
         super(FakeMessage, self).__init__()
         self.attrs = attrs
         self.values = values
@@ -37,18 +42,23 @@ class FakeMessage(object):
         self._latlons = latlons
 
     def latlons(self):
+        """Get the latlons."""
         return self._latlons
 
     def __getitem__(self, item):
+        """Get item."""
         return self.attrs[item]
 
     def valid_key(self, key):
+        """Check if key is valid."""
         return True
 
 
 class FakeGRIB(object):
     """Fake GRIB file returned by pygrib.open."""
+
     def __init__(self, messages=None, proj_params=None, latlons=None):
+        """Init the fake grib file."""
         super(FakeGRIB, self).__init__()
         if messages is not None:
             self._messages = messages
@@ -82,26 +92,31 @@ class FakeGRIB(object):
         self.messages = len(self._messages)
 
     def message(self, msg_num):
+        """Fake message."""
         return self._messages[msg_num - 1]
 
     def seek(self, loc):
+        """Fake seek."""
         return
 
     def __iter__(self):
+        """Iterate over messages."""
         return iter(self._messages)
 
     def __enter__(self):
+        """Enter the context."""
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
+        """Exit the context."""
         pass
 
 
 class TestHSAFFileHandler(unittest.TestCase):
-    """Test HSAF Reader"""
+    """Test HSAF Reader."""
 
     def setUp(self):
-        """Wrap pygrib to read fake data"""
+        """Wrap pygrib to read fake data."""
         try:
             import pygrib
         except ImportError:
@@ -115,10 +130,7 @@ class TestHSAFFileHandler(unittest.TestCase):
 
     @mock.patch('satpy.readers.hsaf_grib.pygrib.open', return_value=FakeGRIB())
     def test_init(self, pg):
-        """
-        Test the init function, ensure that the correct dates and metadata
-        are returned
-        """
+        """Test the init function, ensure that the correct dates and metadata are returned."""
         pg.open.return_value = FakeGRIB()
         correct_dt = datetime(2019, 6, 3, 16, 45, 0)
         from satpy.readers.hsaf_grib import HSAFFileHandler
@@ -130,36 +142,30 @@ class TestHSAFFileHandler(unittest.TestCase):
 
     @mock.patch('satpy.readers.hsaf_grib.pygrib.open', return_value=FakeGRIB())
     def test_get_area_def(self, pg):
-        """
-        Test the area definition setup, checks the size and extent
-        """
+        """Test the area definition setup, checks the size and extent."""
         pg.open.return_value = FakeGRIB()
         from satpy.readers.hsaf_grib import HSAFFileHandler
         fh = HSAFFileHandler('filename', mock.MagicMock(), mock.MagicMock())
         area_def = HSAFFileHandler.get_area_def(fh, 'H03B')
-        self.assertEqual(area_def.x_size, 3712)
+        self.assertEqual(area_def.width, 3712)
         self.assertAlmostEqual(area_def.area_extent[0], -5569209.3026, places=3)
         self.assertAlmostEqual(area_def.area_extent[3], 5587721.9097, places=3)
 
     @mock.patch('satpy.readers.hsaf_grib.pygrib.open', return_value=FakeGRIB())
     def test_get_dataset(self, pg):
-        """
-        Test reading the actual datasets from a grib file
-        """
+        """Test reading the actual datasets from a grib file."""
         pg.open.return_value = FakeGRIB()
         from satpy.readers.hsaf_grib import HSAFFileHandler
         # Instantaneous precipitation
         fh = HSAFFileHandler('filename', mock.MagicMock(), mock.MagicMock())
         fh.filename = "H03B"
-        ds_id = mock.Mock()
-        ds_id.name = 'H03B'
+        ds_id = make_dataid(name='H03B')
         data = fh.get_dataset(ds_id, mock.Mock())
         np.testing.assert_array_equal(data.values, np.arange(25.).reshape((5, 5)))
 
         # Accumulated precipitation
         fh = HSAFFileHandler('filename', mock.MagicMock(), mock.MagicMock())
         fh.filename = "H05B"
-        ds_id = mock.Mock()
-        ds_id.name = 'H05B'
+        ds_id = make_dataid(name='H05B')
         data = fh.get_dataset(ds_id, mock.Mock())
         np.testing.assert_array_equal(data.values, np.arange(25.).reshape((5, 5)))
