@@ -331,6 +331,7 @@ def save_test_data(path):
 
 class TestIasiL2So2Bufr(unittest.TestCase):
     """Test IASI l2 SO2 loader."""
+
     def setUp(self):
         """Create temporary file to perform tests with."""
         import tempfile
@@ -386,15 +387,15 @@ class TestIasiL2So2Bufr(unittest.TestCase):
 
             scn.load([name])
 
-            loaded_values = scn.datasets[name].values
+            loaded_values = scn[name].values
 
-            fill_value = scn.datasets[name].attrs['fill_value']
+            fill_value = scn[name].attrs['fill_value']
 
             # replace nans in data loaded from file with the fill value defined in the .yaml
             # to make them comparable
             loaded_values_nan_filled = np.nan_to_num(loaded_values, nan=fill_value)
 
-            key = scn.datasets[name].attrs['key']
+            key = scn[name].attrs['key']
 
             original_values = msg[key]
 
