@@ -22,15 +22,21 @@ from unittest import mock
 from datetime import datetime
 
 import numpy as np
+import pytest
 import xarray as xr
 
-from satpy.readers.seviri_l1b_hrit import (HRITMSGFileHandler, HRITMSGPrologueFileHandler, HRITMSGEpilogueFileHandler,
-                                           NoValidOrbitParams, pad_data)
-from satpy.readers.seviri_base import CHANNEL_NAMES, VIS_CHANNELS
+from satpy.readers.seviri_l1b_hrit import (
+    HRITMSGFileHandler, HRITMSGPrologueFileHandler, HRITMSGEpilogueFileHandler,
+    NoValidOrbitParams
+)
 from satpy.tests.utils import make_dataid
+from satpy.tests.reader_tests.test_seviri_l1b_calibration import (
+    TestFileHandlerCalibrationBase
+)
 
 from numpy import testing as npt
 
+
 def new_get_hd(instance, hdr_info):
     """Generate some metadata."""
     instance.mda = {'spectral_channel_id': 1}
@@ -105,7 +111,7 @@ class TestHRITMSGFileHandlerHRV(unittest.TestCase):
                     self.reader.mda['projection_parameters']['a'] = 6378169.0
                     self.reader.mda['projection_parameters']['b'] = 6356583.8
                     self.reader.mda['projection_parameters']['h'] = 35785831.0
-                    self.reader.mda['projection_parameters']['SSP_longitude'] = 44
+                    self.reader.mda['projection_parameters']['SSP_longitude'] = 0.0
                     self.reader.mda['projection_parameters']['SSP_latitude'] = 0.0
                     self.reader.mda['orbital_parameters'] = {}
                     self.reader.mda['orbital_parameters']['satellite_nominal_longitude'] = 47
@@ -117,8 +123,8 @@ class TestHRITMSGFileHandlerHRV(unittest.TestCase):
                     self.reader.mda['planned_start_segment_number'] = 1
 
                     tline = np.zeros(nlines, dtype=[('days', '>u2'), ('milliseconds', '>u4')])
-                    tline['days'][1:-1] = 21246 * np.ones(nlines-2)  # 2016-03-03
-                    tline['milliseconds'][1:-1] = np.arange(nlines-2)
+                    tline['days'][1:-1] = 21246 * np.ones(nlines - 2)  # 2016-03-03
+                    tline['milliseconds'][1:-1] = np.arange(nlines - 2)
                     self.reader.mda['image_segment_line_quality'] = {'line_mean_acquisition': tline}
 
     @mock.patch('satpy.readers.hrit_base.np.memmap')
@@ -159,7 +165,7 @@ class TestHRITMSGFileHandlerHRV(unittest.TestCase):
             'satellite_longitude': self.reader.mda['projection_parameters']['SSP_longitude'],
             'satellite_latitude': self.reader.mda['projection_parameters']['SSP_latitude'],
             'satellite_altitude': self.reader.mda['projection_parameters']['h'],
-            'orbital_parameters': {'projection_longitude': 44,
+            'orbital_parameters': {'projection_longitude': 0.,
                                    'projection_latitude': 0.,
                                    'projection_altitude': 35785831.0,
                                    'satellite_nominal_longitude': 47,
@@ -206,7 +212,7 @@ class TestHRITMSGFileHandlerHRV(unittest.TestCase):
             'satellite_longitude': self.reader.mda['projection_parameters']['SSP_longitude'],
             'satellite_latitude': self.reader.mda['projection_parameters']['SSP_latitude'],
             'satellite_altitude': self.reader.mda['projection_parameters']['h'],
-            'orbital_parameters': {'projection_longitude': 44,
+            'orbital_parameters': {'projection_longitude': 0.,
                                    'projection_latitude': 0.,
                                    'projection_altitude': 35785831.0,
                                    'satellite_nominal_longitude': 47,
@@ -224,24 +230,10 @@ class TestHRITMSGFileHandlerHRV(unittest.TestCase):
         self.assertTrue(np.all(res['acq_time'] == timestamps))
         self.assertEqual(res['acq_time'].attrs['long_name'], 'Mean scanline acquisition time')
 
-    def test_pad_data(self):
-        """Test the hrv padding."""
-        data = xr.DataArray(data=np.zeros((1, 10)), dims=('y', 'x'))
-        east_bound = 4
-        west_bound = 13
-        final_size = (1, 20)
-        res = pad_data(data, final_size, east_bound, west_bound)
-        expected = np.array([[np.nan, np.nan, np.nan,  0.,  0.,  0.,  0.,  0.,  0.,  0.,  0.,  0.,  0.,
-                              np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan]])
-        np.testing.assert_allclose(res, expected)
-
-        east_bound = 3
-        self.assertRaises(IndexError, pad_data, data, final_size, east_bound, west_bound)
-
     def test_get_area_def(self):
         """Test getting the area def."""
         from pyresample.utils import proj4_radius_parameters
-        area = self.reader.get_area_def(make_dataid(name='HRV'))
+        area = self.reader.get_area_def(make_dataid(name='HRV', resolution=1000))
         self.assertEqual(area.area_extent,
                          (-45561979844414.07, -3720765401003.719, 45602912357076.38, 77771774058.38356))
         proj_dict = area.proj_dict
@@ -249,16 +241,19 @@ class TestHRITMSGFileHandlerHRV(unittest.TestCase):
         self.assertEqual(a, 6378169.0)
         self.assertEqual(b, 6356583.8)
         self.assertEqual(proj_dict['h'], 35785831.0)
-        self.assertEqual(proj_dict['lon_0'], 44.0)
+        self.assertEqual(proj_dict['lon_0'], 0.0)
         self.assertEqual(proj_dict['proj'], 'geos')
         self.assertEqual(proj_dict['units'], 'm')
         self.reader.fill_hrv = False
-        area = self.reader.get_area_def(make_dataid(name='HRV'))
+        area = self.reader.get_area_def(make_dataid(name='HRV', resolution=1000))
         npt.assert_allclose(area.defs[0].area_extent,
                             (-22017598561055.01, -2926674655354.9604, 23564847539690.22, 77771774058.38356))
         npt.assert_allclose(area.defs[1].area_extent,
                             (-30793529275853.656, -3720765401003.719, 14788916824891.568, -2926674655354.9604))
 
+        self.assertEqual(area.defs[0].area_id, 'msg_seviri_fes_1km')
+        self.assertEqual(area.defs[1].area_id, 'msg_seviri_fes_1km')
+
 
 class TestHRITMSGFileHandler(unittest.TestCase):
     """Test the HRITFileHandler."""
@@ -309,7 +304,7 @@ class TestHRITMSGFileHandler(unittest.TestCase):
                     self.reader.mda['projection_parameters']['a'] = 6378169.0
                     self.reader.mda['projection_parameters']['b'] = 6356583.8
                     self.reader.mda['projection_parameters']['h'] = 35785831.0
-                    self.reader.mda['projection_parameters']['SSP_longitude'] = 44
+                    self.reader.mda['projection_parameters']['SSP_longitude'] = 9.5
                     self.reader.mda['projection_parameters']['SSP_latitude'] = 0.0
                     self.reader.mda['orbital_parameters'] = {}
                     self.reader.mda['orbital_parameters']['satellite_nominal_longitude'] = 47
@@ -319,20 +314,20 @@ class TestHRITMSGFileHandler(unittest.TestCase):
                     self.reader.mda['orbital_parameters']['satellite_actual_altitude'] = 35783328
 
                     tline = np.zeros(nlines, dtype=[('days', '>u2'), ('milliseconds', '>u4')])
-                    tline['days'][1:-1] = 21246 * np.ones(nlines-2)  # 2016-03-03
-                    tline['milliseconds'][1:-1] = np.arange(nlines-2)
+                    tline['days'][1:-1] = 21246 * np.ones(nlines - 2)  # 2016-03-03
+                    tline['milliseconds'][1:-1] = np.arange(nlines - 2)
                     self.reader.mda['image_segment_line_quality'] = {'line_mean_acquisition': tline}
 
     def test_get_area_def(self):
         """Test getting the area def."""
         from pyresample.utils import proj4_radius_parameters
-        area = self.reader.get_area_def(make_dataid(name='VIS006'))
+        area = self.reader.get_area_def(make_dataid(name='VIS006', resolution=3000))
         proj_dict = area.proj_dict
         a, b = proj4_radius_parameters(proj_dict)
         self.assertEqual(a, 6378169.0)
         self.assertEqual(b, 6356583.8)
         self.assertEqual(proj_dict['h'], 35785831.0)
-        self.assertEqual(proj_dict['lon_0'], 44.0)
+        self.assertEqual(proj_dict['lon_0'], 9.5)
         self.assertEqual(proj_dict['proj'], 'geos')
         self.assertEqual(proj_dict['units'], 'm')
         self.assertEqual(area.area_extent,
@@ -341,11 +336,13 @@ class TestHRITMSGFileHandler(unittest.TestCase):
 
         # Data shifted by 1.5km to N-W
         self.reader.mda['offset_corrected'] = False
-        area = self.reader.get_area_def(make_dataid(name='VIS006'))
+        area = self.reader.get_area_def(make_dataid(name='VIS006', resolution=3000))
         self.assertEqual(area.area_extent,
                          (-77771772558.38356, -3720765402503.719,
                           30310525627938.438, 77771772558.38356))
 
+        self.assertEqual(area.area_id, 'msg_seviri_rss_3km')
+
     @mock.patch('satpy.readers.hrit_base.np.memmap')
     def test_read_band(self, memmap):
         """Test reading a band."""
@@ -356,89 +353,6 @@ class TestHRITMSGFileHandler(unittest.TestCase):
         res = self.reader.read_band('VIS006', None)
         self.assertEqual(res.shape, (464, 3712))
 
-    @mock.patch('satpy.readers.hrit_base.HRITFileHandler.__init__', return_value=None)
-    @mock.patch('satpy.readers.seviri_l1b_hrit.HRITMSGFileHandler._get_header', autospec=True)
-    @mock.patch('satpy.readers.seviri_base.SEVIRICalibrationHandler._convert_to_radiance')
-    def test_calibrate(self, _convert_to_radiance, get_header, *mocks):
-        """Test selection of calibration coefficients."""
-        shp = (10, 10)
-        counts = xr.DataArray(np.zeros(shp))
-        nominal_gain = np.arange(1, 13)
-        nominal_offset = np.arange(-1, -13, -1)
-        gsics_gain = np.arange(0.1, 1.3, 0.1)
-        gsics_offset = np.arange(-0.1, -1.3, -0.1)
-
-        # Mock prologue & epilogue
-        pro = mock.MagicMock(prologue={'RadiometricProcessing': {
-            'Level15ImageCalibration': {'CalSlope': nominal_gain,
-                                        'CalOffset': nominal_offset},
-            'MPEFCalFeedback': {'GSICSCalCoeff': gsics_gain,
-                                'GSICSOffsetCount': gsics_offset}
-        }})
-        epi = mock.MagicMock(epilogue=None)
-
-        # Mock header readout
-        mda = {'image_segment_line_quality': {'line_validity': np.zeros(shp[0]),
-                                              'line_radiometric_quality': np.zeros(shp[0]),
-                                              'line_geometric_quality': np.zeros(shp[0])}}
-
-        def get_header_patched(self):
-            self.mda = mda
-
-        get_header.side_effect = get_header_patched
-
-        # Test selection of calibration coefficients
-        #
-        # a) Default: Nominal calibration
-        reader = HRITMSGFileHandler(filename=None, filename_info=None, filetype_info=None,
-                                    prologue=pro, epilogue=epi)
-        for ch_id, ch_name in CHANNEL_NAMES.items():
-            reader.channel_name = ch_name
-            reader.mda['spectral_channel_id'] = ch_id
-            reader.calibrate(data=counts, calibration='radiance')
-            _convert_to_radiance.assert_called_with(mock.ANY, nominal_gain[ch_id - 1],
-                                                    nominal_offset[ch_id - 1])
-
-        # b) GSICS calibration for IR channels, nominal calibration for VIS channels
-        reader = HRITMSGFileHandler(filename=None, filename_info=None, filetype_info=None,
-                                    prologue=pro, epilogue=epi, calib_mode='GSICS')
-        for ch_id, ch_name in CHANNEL_NAMES.items():
-            if ch_name in VIS_CHANNELS:
-                gain, offset = nominal_gain[ch_id - 1], nominal_offset[ch_id - 1]
-            else:
-                gain, offset = gsics_gain[ch_id - 1], gsics_offset[ch_id - 1]
-                offset = offset * gain
-
-            reader.channel_name = ch_name
-            reader.mda['spectral_channel_id'] = ch_id
-            reader.calibrate(data=counts, calibration='radiance')
-            _convert_to_radiance.assert_called_with(mock.ANY, gain, offset)
-
-        # c) External calibration coefficients for selected channels, GSICS coefs for remaining
-        #    IR channels, nominal coefs for remaining VIS channels
-        coefs = {'VIS006': {'gain': 1.234, 'offset': -0.1},
-                 'IR_108': {'gain': 2.345, 'offset': -0.2}}
-        reader = HRITMSGFileHandler(filename=None, filename_info=None, filetype_info=None,
-                                    prologue=pro, epilogue=epi, ext_calib_coefs=coefs,
-                                    calib_mode='GSICS')
-        for ch_id, ch_name in CHANNEL_NAMES.items():
-            if ch_name in coefs:
-                gain, offset = coefs[ch_name]['gain'], coefs[ch_name]['offset']
-            elif ch_name not in VIS_CHANNELS:
-                gain, offset = gsics_gain[ch_id - 1], gsics_offset[ch_id - 1]
-                offset = offset * gain
-            else:
-                gain, offset = nominal_gain[ch_id - 1], nominal_offset[ch_id - 1]
-
-            reader.channel_name = ch_name
-            reader.mda['spectral_channel_id'] = ch_id
-            reader.calibrate(data=counts, calibration='radiance')
-            _convert_to_radiance.assert_called_with(mock.ANY, gain, offset)
-
-        # d) Invalid mode
-        self.assertRaises(ValueError, HRITMSGFileHandler, filename=None, filename_info=None,
-                          filetype_info=None, prologue=pro, epilogue=epi, calib_mode='invalid')
-
     @mock.patch('satpy.readers.seviri_l1b_hrit.HRITMSGFileHandler._get_timestamps')
     @mock.patch('satpy.readers.seviri_l1b_hrit.HRITFileHandler.get_dataset')
     @mock.patch('satpy.readers.seviri_l1b_hrit.HRITMSGFileHandler.calibrate')
@@ -467,7 +381,7 @@ class TestHRITMSGFileHandler(unittest.TestCase):
             'satellite_longitude': self.reader.mda['projection_parameters']['SSP_longitude'],
             'satellite_latitude': self.reader.mda['projection_parameters']['SSP_latitude'],
             'satellite_altitude': self.reader.mda['projection_parameters']['h'],
-            'orbital_parameters': {'projection_longitude': 44,
+            'orbital_parameters': {'projection_longitude': 9.5,
                                    'projection_latitude': 0.,
                                    'projection_altitude': 35785831.0,
                                    'satellite_nominal_longitude': 47,
@@ -580,8 +494,10 @@ class TestHRITMSGPrologueFileHandler(unittest.TestCase):
     @mock.patch('satpy.readers.hrit_base.HRITFileHandler.__init__', autospec=True)
     def test_extra_kwargs(self, init, *mocks):
         """Test whether the prologue file handler accepts extra keyword arguments."""
+
         def init_patched(self, *args, **kwargs):
             self.mda = {}
+
         init.side_effect = init_patched
 
         HRITMSGPrologueFileHandler(filename=None,
@@ -707,6 +623,7 @@ class TestHRITMSGEpilogueFileHandler(unittest.TestCase):
     @mock.patch('satpy.readers.hrit_base.HRITFileHandler.__init__', autospec=True)
     def setUp(self, init, *mocks):
         """Set up the test case."""
+
         def init_patched(self, *args, **kwargs):
             self.mda = {}
 
@@ -721,6 +638,7 @@ class TestHRITMSGEpilogueFileHandler(unittest.TestCase):
     @mock.patch('satpy.readers.hrit_base.HRITFileHandler.__init__', autospec=True)
     def test_extra_kwargs(self, init, *mocks):
         """Test whether the epilogue file handler accepts extra keyword arguments."""
+
         def init_patched(self, *args, **kwargs):
             self.mda = {}
 
@@ -747,3 +665,105 @@ class TestHRITMSGEpilogueFileHandler(unittest.TestCase):
         self.reader._reduced = 'red'
         self.assertEqual(self.reader.reduce(123), 'red')
         reduce_mda.assert_not_called()
+
+
+class TestHRITMSGCalibration(TestFileHandlerCalibrationBase):
+    """Unit tests for calibration."""
+
+    @pytest.fixture(name='file_handler')
+    def file_handler(self):
+        """Create a mocked file handler."""
+        prolog = {
+            'RadiometricProcessing': {
+                'Level15ImageCalibration': {
+                    'CalSlope': self.gains_nominal,
+                    'CalOffset': self.offsets_nominal,
+                },
+                'MPEFCalFeedback': {
+                    'GSICSCalCoeff': self.gains_gsics,
+                    'GSICSOffsetCount': self.offsets_gsics,
+                }
+            },
+            'ImageDescription': {
+                'Level15ImageProduction': {
+                    'PlannedChanProcessing': self.radiance_types
+                }
+            }
+        }
+        epilog = {
+            'ImageProductionStats': {
+                'ActualScanningSummary': {
+                    'ForwardScanStart': self.scan_time
+                }
+            }
+        }
+        mda = {
+            'image_segment_line_quality': {
+                'line_validity': np.zeros(2),
+                'line_radiometric_quality': np.zeros(2),
+                'line_geometric_quality': np.zeros(2)
+            },
+        }
+
+        with mock.patch(
+            'satpy.readers.seviri_l1b_hrit.HRITMSGFileHandler.__init__',
+            return_value=None
+        ):
+            fh = HRITMSGFileHandler()
+            fh.platform_id = self.platform_id
+            fh.mda = mda
+            fh.prologue = prolog
+            fh.epilogue = epilog
+            return fh
+
+    @pytest.mark.parametrize(
+        ('channel', 'calibration', 'calib_mode', 'use_ext_coefs'),
+        [
+            # VIS channel, internal coefficients
+            ('VIS006', 'counts', 'NOMINAL', False),
+            ('VIS006', 'radiance', 'NOMINAL', False),
+            ('VIS006', 'radiance', 'GSICS', False),
+            ('VIS006', 'reflectance', 'NOMINAL', False),
+            # VIS channel, external coefficients (mode should have no effect)
+            ('VIS006', 'radiance', 'GSICS', True),
+            ('VIS006', 'reflectance', 'NOMINAL', True),
+            # IR channel, internal coefficients
+            ('IR_108', 'counts', 'NOMINAL', False),
+            ('IR_108', 'radiance', 'NOMINAL', False),
+            ('IR_108', 'radiance', 'GSICS', False),
+            ('IR_108', 'brightness_temperature', 'NOMINAL', False),
+            ('IR_108', 'brightness_temperature', 'GSICS', False),
+            # IR channel, external coefficients (mode should have no effect)
+            ('IR_108', 'radiance', 'NOMINAL', True),
+            ('IR_108', 'brightness_temperature', 'GSICS', True),
+            # HRV channel, internal coefficiens
+            ('HRV', 'counts', 'NOMINAL', False),
+            ('HRV', 'radiance', 'NOMINAL', False),
+            ('HRV', 'radiance', 'GSICS', False),
+            ('HRV', 'reflectance', 'NOMINAL', False),
+            # HRV channel, external coefficients (mode should have no effect)
+            ('HRV', 'radiance', 'GSICS', True),
+            ('HRV', 'reflectance', 'NOMINAL', True),
+        ]
+    )
+    def test_calibrate(
+            self, file_handler, counts, channel, calibration, calib_mode,
+            use_ext_coefs
+    ):
+        """Test the calibration."""
+        external_coefs = self.external_coefs if use_ext_coefs else {}
+        expected = self._get_expected(
+            channel=channel,
+            calibration=calibration,
+            calib_mode=calib_mode,
+            use_ext_coefs=use_ext_coefs
+        )
+
+        fh = file_handler
+        fh.mda['spectral_channel_id'] = self.spectral_channel_ids[channel]
+        fh.channel_name = channel
+        fh.calib_mode = calib_mode
+        fh.ext_calib_coefs = external_coefs
+
+        res = fh.calibrate(counts, calibration)
+        xr.testing.assert_allclose(res, expected)
