@@ -66,90 +66,156 @@ DATASET_KEYS = {'GDNBO': 'VIIRS-DNB-GEO',
 class FakeHDF5FileHandler2(FakeHDF5FileHandler):
     """Swap-in HDF5 File Handler."""
 
-    def __init__(self, filename, filename_info, filetype_info, use_tc=None):
-        """Create fake file handler."""
-        super(FakeHDF5FileHandler2, self).__init__(filename, filename_info, filetype_info)
-        self.datasets = filename_info['datasets'].split('-')
-        self.use_tc = use_tc
+    _num_test_granules = 1
 
-    def get_test_content(self, filename, filename_info, filetype_info):
-        """Mimic reader input file content."""
+    def __init__(self, filename, filename_info, filetype_info, include_factors=True):
+        """Create fake file handler."""
+        self.include_factors = include_factors
+        super(FakeHDF5FileHandler2, self).__init__(filename, filename_info, filetype_info)
+
+    @staticmethod
+    def _add_basic_metadata_to_file_content(file_content, filename_info):
         start_time = filename_info['start_time']
         end_time = filename_info['end_time'].replace(year=start_time.year,
                                                      month=start_time.month,
                                                      day=start_time.day)
-        final_content = {}
-        for dataset in self.datasets:
-            dataset_group = DATASET_KEYS[dataset]
-            prefix1 = 'Data_Products/{dataset_group}'.format(dataset_group=dataset_group)
-            prefix2 = '{prefix}/{dataset_group}_Aggr'.format(prefix=prefix1, dataset_group=dataset_group)
-            prefix3 = 'All_Data/{dataset_group}_All'.format(dataset_group=dataset_group)
-            prefix4 = '{prefix}/{dataset_group}_Gran_0'.format(prefix=prefix1, dataset_group=dataset_group)
-            begin_date = start_time.strftime('%Y%m%d')
-            begin_time = start_time.strftime('%H%M%S.%fZ')
-            ending_date = end_time.strftime('%Y%m%d')
-            ending_time = end_time.strftime('%H%M%S.%fZ')
-            if filename[:3] == 'SVI':
-                geo_prefix = 'GIMGO'
-            elif filename[:3] == 'SVM':
-                geo_prefix = 'GMODO'
-            else:
-                geo_prefix = None
-            file_content = {
-                "{prefix2}/attr/AggregateNumberGranules": 1,
-                "{prefix4}/attr/N_Number_Of_Scans": 48,
-                "{prefix2}/attr/AggregateBeginningDate": begin_date,
-                "{prefix2}/attr/AggregateBeginningTime": begin_time,
-                "{prefix2}/attr/AggregateEndingDate": ending_date,
-                "{prefix2}/attr/AggregateEndingTime": ending_time,
-                "{prefix2}/attr/G-Ring_Longitude": np.array([0.0, 0.1, 0.2, 0.3]),
-                "{prefix2}/attr/G-Ring_Latitude": np.array([0.0, 0.1, 0.2, 0.3]),
-                "{prefix2}/attr/AggregateBeginningOrbitNumber": "{0:d}".format(filename_info['orbit']),
-                "{prefix2}/attr/AggregateEndingOrbitNumber": "{0:d}".format(filename_info['orbit']),
-                "{prefix1}/attr/Instrument_Short_Name": "VIIRS",
-                "/attr/Platform_Short_Name": "NPP",
-            }
-            if geo_prefix:
-                file_content['/attr/N_GEO_Ref'] = geo_prefix + filename[5:]
-            for k, v in list(file_content.items()):
-                file_content[k.format(prefix1=prefix1, prefix2=prefix2, prefix3=prefix3, prefix4=prefix4)] = v
+        begin_date = start_time.strftime('%Y%m%d')
+        begin_time = start_time.strftime('%H%M%S.%fZ')
+        ending_date = end_time.strftime('%Y%m%d')
+        ending_time = end_time.strftime('%H%M%S.%fZ')
+        new_file_content = {
+            "{prefix2}/attr/AggregateNumberGranules": 1,
+            "{prefix2}/attr/AggregateBeginningDate": begin_date,
+            "{prefix2}/attr/AggregateBeginningTime": begin_time,
+            "{prefix2}/attr/AggregateEndingDate": ending_date,
+            "{prefix2}/attr/AggregateEndingTime": ending_time,
+            "{prefix2}/attr/G-Ring_Longitude": np.array([0.0, 0.1, 0.2, 0.3]),
+            "{prefix2}/attr/G-Ring_Latitude": np.array([0.0, 0.1, 0.2, 0.3]),
+            "{prefix2}/attr/AggregateBeginningOrbitNumber": "{0:d}".format(filename_info['orbit']),
+            "{prefix2}/attr/AggregateEndingOrbitNumber": "{0:d}".format(filename_info['orbit']),
+            "{prefix1}/attr/Instrument_Short_Name": "VIIRS",
+            "/attr/Platform_Short_Name": "NPP",
+        }
+        file_content.update(new_file_content)
 
-            if filename[:3] in ['SVM', 'SVI', 'SVD']:
-                if filename[2:5] in ['M{:02d}'.format(x) for x in range(12)] + ['I01', 'I02', 'I03']:
-                    keys = ['Radiance', 'Reflectance']
-                elif filename[2:5] in ['M{:02d}'.format(x) for x in range(12, 17)] + ['I04', 'I05']:
-                    keys = ['Radiance', 'BrightnessTemperature']
-                else:
-                    # DNB
-                    keys = ['Radiance']
+    @staticmethod
+    def _add_granule_specific_info_to_file_content(
+            file_content, dataset_group, num_granules, gran_group_prefix):
+        lats_lists = [
+            np.array(
+                [
+                    67.969505, 65.545685, 63.103046, 61.853905, 55.169273,
+                    57.062447, 58.86063, 66.495514
+                ],
+                dtype=np.float32),
+            np.array(
+                [
+                    72.74879, 70.2493, 67.84738, 66.49691, 58.77254,
+                    60.465942, 62.11525, 71.08249
+                ],
+                dtype=np.float32),
+            np.array(
+                [
+                    77.393425, 74.977875, 72.62976, 71.083435, 62.036346,
+                    63.465122, 64.78075, 75.36842
+                ],
+                dtype=np.float32),
+            np.array(
+                [
+                    81.67615, 79.49934, 77.278656, 75.369415, 64.72178,
+                    65.78417, 66.66166, 79.00025
+                ],
+                dtype=np.float32),
+        ]
+        lons_lists = [
+            np.array(
+                [
+                    50.51393, 49.566296, 48.865967, 18.96082, -4.0238385,
+                    -7.05221, -10.405702, 14.638646
+                ],
+                dtype=np.float32),
+            np.array(
+                [
+                    53.52594, 51.685738, 50.439102, 14.629087, -10.247547,
+                    -13.951393, -18.256989, 8.36572
+                ],
+                dtype=np.float32),
+            np.array(
+                [
+                    59.386833, 55.770416, 53.38952, 8.353765, -18.062435,
+                    -22.608992, -27.867302, -1.3537619
+                ],
+                dtype=np.float32),
+            np.array(
+                [
+                    72.50243, 64.17125, 59.15234, -1.3654504, -27.620953,
+                    -33.091743, -39.28113, -17.749891
+                ],
+                dtype=np.float32)
+        ]
+        file_content["{prefix3}/NumberOfScans"] = np.array([48] * num_granules)
+        for granule_idx in range(num_granules):
+            prefix_gran = '{prefix}/{dataset_group}_Gran_{idx}'.format(prefix=gran_group_prefix,
+                                                                       dataset_group=dataset_group,
+                                                                       idx=granule_idx)
+            file_content[prefix_gran + '/attr/N_Number_Of_Scans'] = 48
+            file_content[prefix_gran + '/attr/G-Ring_Longitude'] = lons_lists[granule_idx]
+            file_content[prefix_gran + '/attr/G-Ring_Latitude'] = lats_lists[granule_idx]
 
-                for k in keys:
-                    k = prefix3 + "/" + k
-                    file_content[k] = DEFAULT_FILE_DATA.copy()
-                    file_content[k + "/shape"] = DEFAULT_FILE_SHAPE
-                    file_content[k + "Factors"] = DEFAULT_FILE_FACTORS.copy()
-            elif filename[0] == 'G':
-                if filename[:5] in ['GMODO', 'GIMGO']:
-                    lon_data = np.linspace(15, 55, DEFAULT_FILE_SHAPE[1]).astype(DEFAULT_FILE_DTYPE)
-                    lat_data = np.linspace(55, 75, DEFAULT_FILE_SHAPE[1]).astype(DEFAULT_FILE_DTYPE)
-                else:
-                    lon_data = np.linspace(5, 45, DEFAULT_FILE_SHAPE[1]).astype(DEFAULT_FILE_DTYPE)
-                    lat_data = np.linspace(45, 65, DEFAULT_FILE_SHAPE[1]).astype(DEFAULT_FILE_DTYPE)
+    def _add_data_info_to_file_content(self, file_content, filename, data_var_prefix):
+        if filename[2:5] in ['M{:02d}'.format(x) for x in range(12)] + ['I01', 'I02', 'I03']:
+            keys = ['Radiance', 'Reflectance']
+        elif filename[2:5] in ['M{:02d}'.format(x) for x in range(12, 17)] + ['I04', 'I05']:
+            keys = ['Radiance', 'BrightnessTemperature']
+        else:
+            # DNB
+            keys = ['Radiance']
 
-                for k in ["Latitude"]:
-                    k = prefix3 + "/" + k
-                    file_content[k] = lat_data
-                    file_content[k] = np.repeat([file_content[k]], DEFAULT_FILE_SHAPE[0], axis=0)
-                    file_content[k + "/shape"] = DEFAULT_FILE_SHAPE
-                for k in ["Longitude"]:
-                    k = prefix3 + "/" + k
-                    file_content[k] = lon_data
-                    file_content[k] = np.repeat([file_content[k]], DEFAULT_FILE_SHAPE[0], axis=0)
-                    file_content[k + "/shape"] = DEFAULT_FILE_SHAPE
+        for k in keys:
+            k = data_var_prefix + "/" + k
+            file_content[k] = DEFAULT_FILE_DATA.copy()
+            file_content[k + "/shape"] = DEFAULT_FILE_SHAPE
+            if self.include_factors:
+                file_content[k + "Factors"] = DEFAULT_FILE_FACTORS.copy()
 
-        final_content.update(file_content)
+    @staticmethod
+    def _add_geolocation_info_to_file_content(file_content, filename, data_var_prefix):
+        if filename[:5] in ['GMODO', 'GIMGO']:
+            lon_data = np.linspace(15, 55, DEFAULT_FILE_SHAPE[1]).astype(DEFAULT_FILE_DTYPE)
+            lat_data = np.linspace(55, 75, DEFAULT_FILE_SHAPE[1]).astype(DEFAULT_FILE_DTYPE)
+        else:
+            lon_data = np.linspace(5, 45, DEFAULT_FILE_SHAPE[1]).astype(DEFAULT_FILE_DTYPE)
+            lat_data = np.linspace(45, 65, DEFAULT_FILE_SHAPE[1]).astype(DEFAULT_FILE_DTYPE)
 
-        # convert to xarrays
+        for k in ["Latitude"]:
+            k = data_var_prefix + "/" + k
+            file_content[k] = lat_data
+            file_content[k] = np.repeat([file_content[k]], DEFAULT_FILE_SHAPE[0], axis=0)
+            file_content[k + "/shape"] = DEFAULT_FILE_SHAPE
+        for k in ["Longitude"]:
+            k = data_var_prefix + "/" + k
+            file_content[k] = lon_data
+            file_content[k] = np.repeat([file_content[k]], DEFAULT_FILE_SHAPE[0], axis=0)
+            file_content[k + "/shape"] = DEFAULT_FILE_SHAPE
+        for k in ["SolarZenithAngle"]:
+            k = data_var_prefix + "/" + k
+            file_content[k] = lon_data  # close enough to SZA
+            file_content[k] = np.repeat([file_content[k]], DEFAULT_FILE_SHAPE[0], axis=0)
+            file_content[k + "/shape"] = DEFAULT_FILE_SHAPE
+
+    @staticmethod
+    def _add_geo_ref(file_content, filename):
+        if filename[:3] == 'SVI':
+            geo_prefix = 'GIMGO'
+        elif filename[:3] == 'SVM':
+            geo_prefix = 'GMODO'
+        else:
+            geo_prefix = None
+        if geo_prefix:
+            file_content['/attr/N_GEO_Ref'] = geo_prefix + filename[5:]
+
+    @staticmethod
+    def _convert_numpy_content_to_dataarray(final_content):
         from xarray import DataArray
         import dask.array as da
         for key, val in final_content.items():
@@ -160,6 +226,30 @@ class FakeHDF5FileHandler2(FakeHDF5FileHandler):
                 else:
                     final_content[key] = DataArray(val)
 
+    def get_test_content(self, filename, filename_info, filetype_info):
+        """Mimic reader input file content."""
+        final_content = {}
+        for dataset in self.datasets:
+            dataset_group = DATASET_KEYS[dataset]
+            prefix1 = 'Data_Products/{dataset_group}'.format(dataset_group=dataset_group)
+            prefix2 = '{prefix}/{dataset_group}_Aggr'.format(prefix=prefix1, dataset_group=dataset_group)
+            prefix3 = 'All_Data/{dataset_group}_All'.format(dataset_group=dataset_group)
+
+            file_content = {}
+            self._add_basic_metadata_to_file_content(file_content, filename_info)
+            self._add_granule_specific_info_to_file_content(file_content, dataset_group,
+                                                            self._num_test_granules, prefix1)
+            self._add_geo_ref(file_content, filename)
+
+            for k, v in list(file_content.items()):
+                file_content[k.format(prefix1=prefix1, prefix2=prefix2, prefix3=prefix3)] = v
+
+            if filename[:3] in ['SVM', 'SVI', 'SVD']:
+                self._add_data_info_to_file_content(file_content, filename, prefix3)
+            elif filename[0] == 'G':
+                self._add_geolocation_info_to_file_content(file_content, filename, prefix3)
+            final_content.update(file_content)
+        self._convert_numpy_content_to_dataarray(final_content)
         return final_content
 
 
@@ -168,6 +258,39 @@ class TestVIIRSSDRReader(unittest.TestCase):
 
     yaml_file = "viirs_sdr.yaml"
 
+    def _assert_reflectance_properties(self, data_arr, num_scans=16, with_area=True):
+        self.assertTrue(np.issubdtype(data_arr.dtype, np.float32))
+        self.assertEqual(data_arr.attrs['calibration'], 'reflectance')
+        self.assertEqual(data_arr.attrs['units'], '%')
+        self.assertEqual(data_arr.attrs['rows_per_scan'], num_scans)
+        if with_area:
+            self.assertIn('area', data_arr.attrs)
+            self.assertIsNotNone(data_arr.attrs['area'])
+        else:
+            self.assertNotIn('area', data_arr.attrs)
+
+    def _assert_bt_properties(self, data_arr, num_scans=16, with_area=True):
+        self.assertTrue(np.issubdtype(data_arr.dtype, np.float32))
+        self.assertEqual(data_arr.attrs['calibration'], 'brightness_temperature')
+        self.assertEqual(data_arr.attrs['units'], 'K')
+        self.assertEqual(data_arr.attrs['rows_per_scan'], num_scans)
+        if with_area:
+            self.assertIn('area', data_arr.attrs)
+            self.assertIsNotNone(data_arr.attrs['area'])
+        else:
+            self.assertNotIn('area', data_arr.attrs)
+
+    def _assert_dnb_radiance_properties(self, data_arr, with_area=True):
+        self.assertTrue(np.issubdtype(data_arr.dtype, np.float32))
+        self.assertEqual(data_arr.attrs['calibration'], 'radiance')
+        self.assertEqual(data_arr.attrs['units'], 'W m-2 sr-1')
+        self.assertEqual(data_arr.attrs['rows_per_scan'], 16)
+        if with_area:
+            self.assertIn('area', data_arr.attrs)
+            self.assertIsNotNone(data_arr.attrs['area'])
+        else:
+            self.assertNotIn('area', data_arr.attrs)
+
     def setUp(self):
         """Wrap HDF5 file handler with our own fake handler."""
         from satpy.config import config_search_paths
@@ -189,7 +312,7 @@ class TestVIIRSSDRReader(unittest.TestCase):
         loadables = r.select_files_from_pathnames([
             'SVI01_npp_d20120225_t1801245_e1802487_b01708_c20120226002130255476_noaa_ops.h5',
         ])
-        self.assertTrue(len(loadables), 1)
+        self.assertEqual(len(loadables), 1)
         r.create_filehandlers(loadables)
         # make sure we have some files
         self.assertTrue(r.file_handlers)
@@ -202,10 +325,10 @@ class TestVIIRSSDRReader(unittest.TestCase):
                         filter_parameters={
                             'start_time': datetime(2012, 2, 26)
                         })
-        loadables = r.select_files_from_pathnames([
+        fhs = r.create_filehandlers([
             'SVI01_npp_d20120225_t1801245_e1802487_b01708_c20120226002130255476_noaa_ops.h5',
         ])
-        self.assertTrue(len(loadables), 0)
+        self.assertEqual(len(fhs), 0)
 
     def test_init_end_time_beyond(self):
         """Test basic init with end_time before the provided files."""
@@ -215,10 +338,10 @@ class TestVIIRSSDRReader(unittest.TestCase):
                         filter_parameters={
                             'end_time': datetime(2012, 2, 24)
                         })
-        loadables = r.select_files_from_pathnames([
+        fhs = r.create_filehandlers([
             'SVI01_npp_d20120225_t1801245_e1802487_b01708_c20120226002130255476_noaa_ops.h5',
         ])
-        self.assertTrue(len(loadables), 0)
+        self.assertEqual(len(fhs), 0)
 
     def test_init_start_end_time(self):
         """Test basic init with end_time before the provided files."""
@@ -232,7 +355,7 @@ class TestVIIRSSDRReader(unittest.TestCase):
         loadables = r.select_files_from_pathnames([
             'SVI01_npp_d20120225_t1801245_e1802487_b01708_c20120226002130255476_noaa_ops.h5',
         ])
-        self.assertTrue(len(loadables), 1)
+        self.assertEqual(len(loadables), 1)
         r.create_filehandlers(loadables)
         # make sure we have some files
         self.assertTrue(r.file_handlers)
@@ -269,10 +392,7 @@ class TestVIIRSSDRReader(unittest.TestCase):
                      ])
         self.assertEqual(len(ds), 11)
         for d in ds.values():
-            self.assertEqual(d.attrs['calibration'], 'reflectance')
-            self.assertEqual(d.attrs['units'], '%')
-            self.assertEqual(d.attrs['rows_per_scan'], 16)
-            self.assertNotIn('area', d.attrs)
+            self._assert_reflectance_properties(d, with_area=False)
 
     def test_load_all_m_reflectances_find_geo(self):
         """Load all M band reflectances with geo files not specified but existing."""
@@ -314,11 +434,7 @@ class TestVIIRSSDRReader(unittest.TestCase):
 
         self.assertEqual(len(ds), 11)
         for d in ds.values():
-            self.assertEqual(d.attrs['calibration'], 'reflectance')
-            self.assertEqual(d.attrs['units'], '%')
-            self.assertEqual(d.attrs['rows_per_scan'], 16)
-            self.assertIn('area', d.attrs)
-            self.assertIsNotNone(d.attrs['area'])
+            self._assert_reflectance_properties(d, with_area=True)
 
     def test_load_all_m_reflectances_provided_geo(self):
         """Load all M band reflectances with geo files provided."""
@@ -353,11 +469,7 @@ class TestVIIRSSDRReader(unittest.TestCase):
                      ])
         self.assertEqual(len(ds), 11)
         for d in ds.values():
-            self.assertEqual(d.attrs['calibration'], 'reflectance')
-            self.assertEqual(d.attrs['units'], '%')
-            self.assertEqual(d.attrs['rows_per_scan'], 16)
-            self.assertIn('area', d.attrs)
-            self.assertIsNotNone(d.attrs['area'])
+            self._assert_reflectance_properties(d, with_area=True)
             self.assertEqual(d.attrs['area'].lons.min(), 5)
             self.assertEqual(d.attrs['area'].lats.min(), 45)
             self.assertEqual(d.attrs['area'].lons.attrs['rows_per_scan'], 16)
@@ -382,7 +494,7 @@ class TestVIIRSSDRReader(unittest.TestCase):
             'GMTCO_npp_d20120225_t1801245_e1802487_b01708_c20120226002130255476_noaa_ops.h5',
             'GMODO_npp_d20120225_t1801245_e1802487_b01708_c20120226002130255476_noaa_ops.h5',
         ])
-        r.create_filehandlers(loadables)
+        r.create_filehandlers(loadables, {'use_tc': False})
         ds = r.load(['M01',
                      'M02',
                      'M03',
@@ -397,11 +509,7 @@ class TestVIIRSSDRReader(unittest.TestCase):
                      ])
         self.assertEqual(len(ds), 11)
         for d in ds.values():
-            self.assertEqual(d.attrs['calibration'], 'reflectance')
-            self.assertEqual(d.attrs['units'], '%')
-            self.assertEqual(d.attrs['rows_per_scan'], 16)
-            self.assertIn('area', d.attrs)
-            self.assertIsNotNone(d.attrs['area'])
+            self._assert_reflectance_properties(d, with_area=True)
             self.assertEqual(d.attrs['area'].lons.min(), 15)
             self.assertEqual(d.attrs['area'].lats.min(), 55)
             self.assertEqual(d.attrs['area'].lons.attrs['rows_per_scan'], 16)
@@ -425,7 +533,7 @@ class TestVIIRSSDRReader(unittest.TestCase):
             'SVM11_npp_d20120225_t1801245_e1802487_b01708_c20120226002130255476_noaa_ops.h5',
             'GMODO_npp_d20120225_t1801245_e1802487_b01708_c20120226002130255476_noaa_ops.h5',
         ])
-        r.create_filehandlers(loadables)
+        r.create_filehandlers(loadables, {'use_tc': None})
         ds = r.load(['M01',
                      'M02',
                      'M03',
@@ -440,11 +548,7 @@ class TestVIIRSSDRReader(unittest.TestCase):
                      ])
         self.assertEqual(len(ds), 11)
         for d in ds.values():
-            self.assertEqual(d.attrs['calibration'], 'reflectance')
-            self.assertEqual(d.attrs['units'], '%')
-            self.assertEqual(d.attrs['rows_per_scan'], 16)
-            self.assertIn('area', d.attrs)
-            self.assertIsNotNone(d.attrs['area'])
+            self._assert_reflectance_properties(d, with_area=True)
             self.assertEqual(d.attrs['area'].lons.min(), 15)
             self.assertEqual(d.attrs['area'].lats.min(), 55)
             self.assertEqual(d.attrs['area'].lons.attrs['rows_per_scan'], 16)
@@ -471,8 +575,26 @@ class TestVIIRSSDRReader(unittest.TestCase):
                      ])
         self.assertEqual(len(ds), 5)
         for d in ds.values():
-            self.assertEqual(d.attrs['calibration'], 'brightness_temperature')
-            self.assertEqual(d.attrs['units'], 'K')
+            self._assert_bt_properties(d, with_area=True)
+
+    def test_load_dnb_sza_no_factors(self):
+        """Load DNB solar zenith angle with no scaling factors.
+
+        The angles in VIIRS SDRs should never have scaling factors so we test
+        it that way.
+
+        """
+        from satpy.readers import load_reader
+        r = load_reader(self.reader_configs)
+        loadables = r.select_files_from_pathnames([
+            'GDNBO_npp_d20120225_t1801245_e1802487_b01708_c20120226002130255476_noaa_ops.h5',
+        ])
+        r.create_filehandlers(loadables, {'include_factors': False})
+        ds = r.load(['dnb_solar_zenith_angle'])
+        self.assertEqual(len(ds), 1)
+        for d in ds.values():
+            self.assertTrue(np.issubdtype(d.dtype, np.float32))
+            self.assertEqual(d.attrs['units'], 'degrees')
             self.assertEqual(d.attrs['rows_per_scan'], 16)
             self.assertIn('area', d.attrs)
             self.assertIsNotNone(d.attrs['area'])
@@ -480,7 +602,7 @@ class TestVIIRSSDRReader(unittest.TestCase):
     def test_load_all_m_radiances(self):
         """Load all M band radiances."""
         from satpy.readers import load_reader
-        from satpy import DatasetID
+        from satpy.tests.utils import make_dsq
         r = load_reader(self.reader_configs)
         loadables = r.select_files_from_pathnames([
             'SVM01_npp_d20120225_t1801245_e1802487_b01708_c20120226002130255476_noaa_ops.h5',
@@ -503,25 +625,26 @@ class TestVIIRSSDRReader(unittest.TestCase):
         ])
         r.create_filehandlers(loadables)
         ds = r.load([
-            DatasetID(name='M01', calibration='radiance', modifiers=None),
-            DatasetID(name='M02', calibration='radiance', modifiers=None),
-            DatasetID(name='M03', calibration='radiance', modifiers=None),
-            DatasetID(name='M04', calibration='radiance', modifiers=None),
-            DatasetID(name='M05', calibration='radiance', modifiers=None),
-            DatasetID(name='M06', calibration='radiance', modifiers=None),
-            DatasetID(name='M07', calibration='radiance', modifiers=None),
-            DatasetID(name='M08', calibration='radiance', modifiers=None),
-            DatasetID(name='M09', calibration='radiance', modifiers=None),
-            DatasetID(name='M10', calibration='radiance', modifiers=None),
-            DatasetID(name='M11', calibration='radiance', modifiers=None),
-            DatasetID(name='M12', calibration='radiance', modifiers=None),
-            DatasetID(name='M13', calibration='radiance', modifiers=None),
-            DatasetID(name='M14', calibration='radiance', modifiers=None),
-            DatasetID(name='M15', calibration='radiance', modifiers=None),
-            DatasetID(name='M16', calibration='radiance', modifiers=None),
+            make_dsq(name='M01', calibration='radiance'),
+            make_dsq(name='M02', calibration='radiance'),
+            make_dsq(name='M03', calibration='radiance'),
+            make_dsq(name='M04', calibration='radiance'),
+            make_dsq(name='M05', calibration='radiance'),
+            make_dsq(name='M06', calibration='radiance'),
+            make_dsq(name='M07', calibration='radiance'),
+            make_dsq(name='M08', calibration='radiance'),
+            make_dsq(name='M09', calibration='radiance'),
+            make_dsq(name='M10', calibration='radiance'),
+            make_dsq(name='M11', calibration='radiance'),
+            make_dsq(name='M12', calibration='radiance'),
+            make_dsq(name='M13', calibration='radiance'),
+            make_dsq(name='M14', calibration='radiance'),
+            make_dsq(name='M15', calibration='radiance'),
+            make_dsq(name='M16', calibration='radiance'),
                      ])
         self.assertEqual(len(ds), 16)
         for d in ds.values():
+            self.assertTrue(np.issubdtype(d.dtype, np.float32))
             self.assertEqual(d.attrs['calibration'], 'radiance')
             self.assertEqual(d.attrs['units'], 'W m-2 um-1 sr-1')
             self.assertEqual(d.attrs['rows_per_scan'], 16)
@@ -540,11 +663,39 @@ class TestVIIRSSDRReader(unittest.TestCase):
         ds = r.load(['DNB'])
         self.assertEqual(len(ds), 1)
         for d in ds.values():
-            self.assertEqual(d.attrs['calibration'], 'radiance')
-            self.assertEqual(d.attrs['units'], 'W m-2 sr-1')
-            self.assertEqual(d.attrs['rows_per_scan'], 16)
-            self.assertIn('area', d.attrs)
-            self.assertIsNotNone(d.attrs['area'])
+            data = d.values
+            # default scale factors are 2 and offset 1
+            # multiply DNB by 10000 should mean the first value of 0 should be:
+            # data * factor * 10000 + offset * 10000
+            # 0 * 2 * 10000 + 1 * 10000 => 10000
+            self.assertEqual(data[0, 0], 10000)
+            # the second value of 1 should be:
+            # 1 * 2 * 10000 + 1 * 10000 => 30000
+            self.assertEqual(data[0, 1], 30000)
+            self._assert_dnb_radiance_properties(d, with_area=True)
+
+    def test_load_dnb_no_factors(self):
+        """Load DNB dataset with no provided scale factors."""
+        from satpy.readers import load_reader
+        r = load_reader(self.reader_configs)
+        loadables = r.select_files_from_pathnames([
+            'SVDNB_npp_d20120225_t1801245_e1802487_b01708_c20120226002130255476_noaa_ops.h5',
+            'GDNBO_npp_d20120225_t1801245_e1802487_b01708_c20120226002130255476_noaa_ops.h5',
+        ])
+        r.create_filehandlers(loadables, {'include_factors': False})
+        ds = r.load(['DNB'])
+        self.assertEqual(len(ds), 1)
+        for d in ds.values():
+            data = d.values
+            # no scale factors, default factor 1 and offset 0
+            # multiply DNB by 10000 should mean the first value of 0 should be:
+            # data * factor * 10000 + offset * 10000
+            # 0 * 1 * 10000 + 0 * 10000 => 0
+            self.assertEqual(data[0, 0], 0)
+            # the second value of 1 should be:
+            # 1 * 1 * 10000 + 0 * 10000 => 10000
+            self.assertEqual(data[0, 1], 10000)
+            self._assert_dnb_radiance_properties(d, with_area=True)
 
     def test_load_i_no_files(self):
         """Load I01 when only DNB files are provided."""
@@ -555,7 +706,7 @@ class TestVIIRSSDRReader(unittest.TestCase):
             'GDNBO_npp_d20120225_t1801245_e1802487_b01708_c20120226002130255476_noaa_ops.h5',
         ])
         r.create_filehandlers(loadables)
-        self.assertNotIn('I01', [x.name for x in r.available_dataset_ids])
+        self.assertNotIn('I01', [x['name'] for x in r.available_dataset_ids])
         ds = r.load(['I01'])
         self.assertEqual(len(ds), 0)
 
@@ -576,11 +727,7 @@ class TestVIIRSSDRReader(unittest.TestCase):
                      ])
         self.assertEqual(len(ds), 3)
         for d in ds.values():
-            self.assertEqual(d.attrs['calibration'], 'reflectance')
-            self.assertEqual(d.attrs['units'], '%')
-            self.assertEqual(d.attrs['rows_per_scan'], 32)
-            self.assertIn('area', d.attrs)
-            self.assertIsNotNone(d.attrs['area'])
+            self._assert_reflectance_properties(d, num_scans=32)
             self.assertEqual(d.attrs['area'].lons.min(), 5)
             self.assertEqual(d.attrs['area'].lats.min(), 45)
             self.assertEqual(d.attrs['area'].lons.attrs['rows_per_scan'], 32)
@@ -601,16 +748,12 @@ class TestVIIRSSDRReader(unittest.TestCase):
                      ])
         self.assertEqual(len(ds), 2)
         for d in ds.values():
-            self.assertEqual(d.attrs['calibration'], 'brightness_temperature')
-            self.assertEqual(d.attrs['units'], 'K')
-            self.assertEqual(d.attrs['rows_per_scan'], 32)
-            self.assertIn('area', d.attrs)
-            self.assertIsNotNone(d.attrs['area'])
+            self._assert_bt_properties(d, num_scans=32)
 
     def test_load_all_i_radiances(self):
         """Load all I band radiances."""
         from satpy.readers import load_reader
-        from satpy import DatasetID
+        from satpy.tests.utils import make_dsq
         r = load_reader(self.reader_configs)
         loadables = r.select_files_from_pathnames([
             'SVI01_npp_d20120225_t1801245_e1802487_b01708_c20120226002130255476_noaa_ops.h5',
@@ -622,14 +765,15 @@ class TestVIIRSSDRReader(unittest.TestCase):
         ])
         r.create_filehandlers(loadables)
         ds = r.load([
-            DatasetID(name='I01', calibration='radiance', modifiers=None),
-            DatasetID(name='I02', calibration='radiance', modifiers=None),
-            DatasetID(name='I03', calibration='radiance', modifiers=None),
-            DatasetID(name='I04', calibration='radiance', modifiers=None),
-            DatasetID(name='I05', calibration='radiance', modifiers=None),
+            make_dsq(name='I01', calibration='radiance'),
+            make_dsq(name='I02', calibration='radiance'),
+            make_dsq(name='I03', calibration='radiance'),
+            make_dsq(name='I04', calibration='radiance'),
+            make_dsq(name='I05', calibration='radiance'),
         ])
         self.assertEqual(len(ds), 5)
         for d in ds.values():
+            self.assertTrue(np.issubdtype(d.dtype, np.float32))
             self.assertEqual(d.attrs['calibration'], 'radiance')
             self.assertEqual(d.attrs['units'], 'W m-2 um-1 sr-1')
             self.assertEqual(d.attrs['rows_per_scan'], 32)
@@ -637,162 +781,10 @@ class TestVIIRSSDRReader(unittest.TestCase):
             self.assertIsNotNone(d.attrs['area'])
 
 
-class FakeHDF5FileHandlerAggr(FakeHDF5FileHandler):
-    """Swap-in HDF5 File Handler."""
+class FakeHDF5FileHandlerAggr(FakeHDF5FileHandler2):
+    """Swap-in HDF5 File Handler with 4 VIIRS Granules per file."""
 
-    def __init__(self, filename, filename_info, filetype_info, use_tc=None):
-        """Create fake aggregated file handler."""
-        super(FakeHDF5FileHandlerAggr, self).__init__(filename, filename_info, filetype_info)
-        self.datasets = filename_info['datasets'].split('-')
-        self.use_tc = use_tc
-
-    def get_test_content(self, filename, filename_info, filetype_info):
-        """Mimic reader input file content."""
-        start_time = filename_info['start_time']
-        end_time = filename_info['end_time'].replace(year=start_time.year,
-                                                     month=start_time.month,
-                                                     day=start_time.day)
-        final_content = {}
-        for dataset in self.datasets:
-            dataset_group = DATASET_KEYS[dataset]
-            prefix1 = 'Data_Products/{dataset_group}'.format(dataset_group=dataset_group)
-            prefix2 = '{prefix}/{dataset_group}_Aggr'.format(prefix=prefix1, dataset_group=dataset_group)
-            prefix3 = 'All_Data/{dataset_group}_All'.format(dataset_group=dataset_group)
-            begin_date = start_time.strftime('%Y%m%d')
-            begin_time = start_time.strftime('%H%M%S.%fZ')
-            ending_date = end_time.strftime('%Y%m%d')
-            ending_time = end_time.strftime('%H%M%S.%fZ')
-            if filename[:3] == 'SVI':
-                geo_prefix = 'GIMGO'
-            elif filename[:3] == 'SVM':
-                geo_prefix = 'GMODO'
-            else:
-                geo_prefix = None
-            file_content = {
-                "{prefix3}/NumberOfScans": np.array([48, 48, 48, 48]),
-                "{prefix2}/attr/AggregateBeginningDate": begin_date,
-                "{prefix2}/attr/AggregateBeginningTime": begin_time,
-                "{prefix2}/attr/AggregateEndingDate": ending_date,
-                "{prefix2}/attr/AggregateEndingTime": ending_time,
-                "{prefix2}/attr/G-Ring_Longitude": np.array([0.0, 0.1, 0.2, 0.3]),
-                "{prefix2}/attr/G-Ring_Latitude": np.array([0.0, 0.1, 0.2, 0.3]),
-                "{prefix2}/attr/AggregateBeginningOrbitNumber": "{0:d}".format(filename_info['orbit']),
-                "{prefix2}/attr/AggregateEndingOrbitNumber": "{0:d}".format(filename_info['orbit']),
-                "{prefix1}/attr/Instrument_Short_Name": "VIIRS",
-                "/attr/Platform_Short_Name": "NPP",
-            }
-
-            lats_lists = [
-                np.array(
-                    [
-                        67.969505, 65.545685, 63.103046, 61.853905, 55.169273,
-                        57.062447, 58.86063, 66.495514
-                    ],
-                    dtype=np.float32),
-                np.array(
-                    [
-                        72.74879, 70.2493, 67.84738, 66.49691, 58.77254,
-                        60.465942, 62.11525, 71.08249
-                    ],
-                    dtype=np.float32),
-                np.array(
-                    [
-                        77.393425, 74.977875, 72.62976, 71.083435, 62.036346,
-                        63.465122, 64.78075, 75.36842
-                    ],
-                    dtype=np.float32),
-                np.array(
-                    [
-                        81.67615, 79.49934, 77.278656, 75.369415, 64.72178,
-                        65.78417, 66.66166, 79.00025
-                    ],
-                    dtype=np.float32)
-            ]
-            lons_lists = [
-                np.array(
-                    [
-                        50.51393, 49.566296, 48.865967, 18.96082, -4.0238385,
-                        -7.05221, -10.405702, 14.638646
-                    ],
-                    dtype=np.float32),
-                np.array(
-                    [
-                        53.52594, 51.685738, 50.439102, 14.629087, -10.247547,
-                        -13.951393, -18.256989, 8.36572
-                    ],
-                    dtype=np.float32),
-                np.array(
-                    [
-                        59.386833, 55.770416, 53.38952, 8.353765, -18.062435,
-                        -22.608992, -27.867302, -1.3537619
-                    ],
-                    dtype=np.float32),
-                np.array(
-                    [
-                        72.50243, 64.17125, 59.15234, -1.3654504, -27.620953,
-                        -33.091743, -39.28113, -17.749891
-                    ],
-                    dtype=np.float32)
-            ]
-
-            for granule in range(4):
-                prefix_gran = '{prefix}/{dataset_group}_Gran_{idx}'.format(prefix=prefix1,
-                                                                           dataset_group=dataset_group,
-                                                                           idx=granule)
-                file_content[prefix_gran + '/attr/G-Ring_Longitude'] = lons_lists[granule]
-                file_content[prefix_gran + '/attr/G-Ring_Latitude'] = lats_lists[granule]
-            if geo_prefix:
-                file_content['/attr/N_GEO_Ref'] = geo_prefix + filename[5:]
-            for k, v in list(file_content.items()):
-                file_content[k.format(prefix1=prefix1, prefix2=prefix2, prefix3=prefix3)] = v
-
-            if filename[:3] in ['SVM', 'SVI', 'SVD']:
-                if filename[2:5] in ['M{:02d}'.format(x) for x in range(12)] + ['I01', 'I02', 'I03']:
-                    keys = ['Radiance', 'Reflectance']
-                elif filename[2:5] in ['M{:02d}'.format(x) for x in range(12, 17)] + ['I04', 'I05']:
-                    keys = ['Radiance', 'BrightnessTemperature']
-                else:
-                    # DNB
-                    keys = ['Radiance']
-
-                for k in keys:
-                    k = prefix3 + "/" + k
-                    file_content[k] = DEFAULT_FILE_DATA.copy()
-                    file_content[k + "/shape"] = DEFAULT_FILE_SHAPE
-                    file_content[k + "Factors"] = DEFAULT_FILE_FACTORS.copy()
-            elif filename[0] == 'G':
-                if filename[:5] in ['GMODO', 'GIMGO']:
-                    lon_data = np.linspace(15, 55, DEFAULT_FILE_SHAPE[1]).astype(DEFAULT_FILE_DTYPE)
-                    lat_data = np.linspace(55, 75, DEFAULT_FILE_SHAPE[1]).astype(DEFAULT_FILE_DTYPE)
-                else:
-                    lon_data = np.linspace(5, 45, DEFAULT_FILE_SHAPE[1]).astype(DEFAULT_FILE_DTYPE)
-                    lat_data = np.linspace(45, 65, DEFAULT_FILE_SHAPE[1]).astype(DEFAULT_FILE_DTYPE)
-
-                for k in ["Latitude"]:
-                    k = prefix3 + "/" + k
-                    file_content[k] = lat_data
-                    file_content[k] = np.repeat([file_content[k]], DEFAULT_FILE_SHAPE[0], axis=0)
-                    file_content[k + "/shape"] = DEFAULT_FILE_SHAPE
-                for k in ["Longitude"]:
-                    k = prefix3 + "/" + k
-                    file_content[k] = lon_data
-                    file_content[k] = np.repeat([file_content[k]], DEFAULT_FILE_SHAPE[0], axis=0)
-                    file_content[k + "/shape"] = DEFAULT_FILE_SHAPE
-
-        final_content.update(file_content)
-
-        # convert to xarrays
-        from xarray import DataArray
-        import dask.array as da
-        for key, val in final_content.items():
-            if isinstance(val, np.ndarray):
-                val = da.from_array(val, chunks=val.shape)
-                if val.ndim > 1:
-                    final_content[key] = DataArray(val, dims=('y', 'x'))
-                else:
-                    final_content[key] = DataArray(val)
-
-        return final_content
+    _num_test_granules = 4
 
 
 class TestAggrVIIRSSDRReader(unittest.TestCase):
