@@ -176,10 +176,12 @@ class TestMultiScene(unittest.TestCase):
         with mock.patch('satpy.multiscene.Scene') as scn_mock:
             mscn = MultiScene.from_files(
                     input_files_abi,
-                    reader='abi_l1b')
+                    reader='abi_l1b',
+                    scene_kwargs={"reader_kwargs": {}})
             assert len(mscn.scenes) == 6
             calls = [mock.call(
-                filenames={'abi_l1b': [in_file_abi]})
+                filenames={'abi_l1b': [in_file_abi]},
+                reader_kwargs={})
                 for in_file_abi in input_files_abi]
             scn_mock.assert_has_calls(calls)
 
